/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlTabhead.h"
#include "HvControlBinop.h"
#include "HvControlDelay.h"
#include "HvControlPack.h"
#include "HvControlCast.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvControlRandom.h"
#include "HvSignalPhasor.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvSignalVar.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_jxc8nh7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eWrLPeWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ZkA0lV1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ugCLphGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_asYb3MXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cSc1V3Cd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_jse1GMo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TaxVq1PI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_frl0xbDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5JlbNHoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Oz5cuyd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LZlB2H7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LfBMXglU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wt9lOsQo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_YfkBLIOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_FFPwH9Q1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l5wdSUCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3F1L2XQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zd9UOrLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OTxvFpgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zV6aIvSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lm5wwypc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ofzQlBi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r0O628DP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ej5YC4v1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pwukIqfi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZnYXelYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5DtrZ7hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M3gzjeWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YSlGfycc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1Fr9IBa0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PlTVLrIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yTkPRrnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_86xO1gGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q83h6iut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Ha4p90s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_57Lwqf7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wFV8jId0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ftr716nN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6VKz2GLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ooIrhKXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T5ZPYz3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7angG404_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8qdNbeAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qC40sKsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Y1bQi8LR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IfC2YEte_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_mYVGVubI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FxTawaSx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uVFhIOxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sDCewse9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9OkeQxW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HkSnukSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W3aSvxoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LSj7L9Ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HaMKtHdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NcgH2cIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hnKHFRKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e1izAppf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kj6SjeF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_56Q0L3QD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4clHKkyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HfyiHprn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_y36gZAy4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_LcUZUHUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_y1HquUdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_5AhXQpEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_p3JYqO4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SZRYyRfP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_TQ6wrOc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_InSFwolO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XVie5Rd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EPGeB1wd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gcjymb3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Azwfge7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2JMrrT7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cs94M7gY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sf3OnOiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_XuFtM1H0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8tUBw3EL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_s2RLzriX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OqSeOw4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_32QZ3iKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rRMlV8NM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_XN3xD77l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZSDyEfRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pd1klUq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MCuSNwug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zM9Wbm9F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XEO7a5IL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFidAGuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qxG6eqYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iRTS7mSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xLMlFkBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H6IrvDWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bt7OvsCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9cjTDhND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_sU5zvxGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XgwwekLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RqePczTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1mWlg4ka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Kp9lX2WD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ubNnlMNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_0NB9mQvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uw7bQCJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YVKQG90N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4006Cx5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lBRhJt20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e9rdIeaw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yAVkc4gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KwJJr6q3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4mQYdruj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_acZqYnVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0YpmNAyW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZqqZ2KE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yzf3Jc5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_k4oIYlfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TY6U4juR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A7NrjUfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ApEgP0Xq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RPhAdHnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5RieiJ5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5zeiANgd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_twLn03Sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JoDXIAax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nPLjJZRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FLxKFNRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lu0PcUik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oggvrxA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zw651bbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcxj0JEZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BmKY0ab5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WoGmfHpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QqH8bE7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rc163Lnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_qF7ovFDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QPCqunoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XQ7PXnPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gOhnUmKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_y3gYDxvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GYDFTj0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_KxdxpacY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aduDC76K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8HAv3pmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZzO2tBfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HpbupGee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2RbfNpyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G9hdoh4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lZQpt6Bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u2OihzGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cYMuXLmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kJAkPPTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_35epTNIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JsSWh20H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kTAXVVae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rd5H5f3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_63h73XxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hHuJWzNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iHg2zev9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_nH1rlWzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_EKayMEtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AumyQcNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nVOkl3X9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vv7O620t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c1ooBwX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yRoo4Hah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k7yIUtp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8bwmD84w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JxFKTcGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iHWbdVcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DvaiUoy4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EBi2ZeCY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_QKI0sWNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_EdKgNVIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qEta91f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sjxga2pX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xXBYzQF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K1RXVXOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OGQO2xKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NHjWuEea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qrdRDvo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_137zSy7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2F8zWUy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eBVMARli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HuiCTeOx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Oem6U7hE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_tqKcplW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nn21Zhdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gkgmWr5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yaEDoK4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UN7uEZz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_343oiKme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q8LJMvjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U7gfNjm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S1LQqgUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xGOCK1Wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2ZwEnOSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_p1FnCjfr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ph6LtCgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_eyu9PmsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p85YztDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YthDV6EY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kP8rnfDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MMiere2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g8UcdYYw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LkNqgh4L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ZB5AFMFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_F9o998ik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5BLqaItw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2O2AVR80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c7TnuvkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tkBSdqt0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AGGiVUtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2sWzRYI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t4wTJIJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CcT4APwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vm8qKQZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qQyBTeQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bgIuO2JX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LhTRrR5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GmG7Z0A3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CpIYPq7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_atxWBLLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rDbqZAtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rfH4OddQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zoTrgGID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ltNKIPH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HDKAsduh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FFbSV7wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_yv9eZCBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GCnptN1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ekvQozLa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_qBrHPAM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_txzS0m3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1sBYLcrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CTqtmFRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MqIi4mwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8NwN9hCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WsKFDzXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J8J3FNWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vtr7MPsj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NfVyOLLT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_i5telGUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sCYjb2Hl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CYjmI4Oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_91yk2Psw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_pf1cY1OZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_seQnfdqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bReImFcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aJF8A82M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eAkhH8Ry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b770Q4C6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_awE6qQaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rGvRRSrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pb2EKpY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3744cYS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OkMxRfdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ZN4CapC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AL14u1rT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gw9nTJi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jiYNmSrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ek5hffi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_70elUr3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ypxSVdoM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_FLWaBFz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_67dsIc73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wlPmPYyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ZYRnMHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NhkvfktU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a4Pq4HaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SHH5jzbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qLIXzP6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Cbu2a9jP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RTg39Stq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ljdfwD3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sGoJGP5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BuGzP4a9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zyJpQ0al_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_dQGshT1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9CizaDQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bALyCEyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fCecfaUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_izsKatBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7PVbieAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qkLBg2yB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IdNjwYSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cN5IfL6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ljnBrrMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ITuL5M9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yn3XTgvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qdEiJlSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nc5wDMUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0NhIRryw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_toAXgDXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qxzSf9pe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_P0BImbC2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_djWOTh2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_sqj6Gv21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qjI5fIs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X2Jaiumj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A7zLq0vn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c8Q4wM3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UJI5oJMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BusX5hzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ShQPLGxc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uVLSVJSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4M92FgSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_arFAj48c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZLCkeDzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IQ5kWxsv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_CGNBqTxo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uOqqeUuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N7ygxQpO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QSEWGBg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PtUv2XZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yhjd3UTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TDJghSyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gS2mI6Tn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kCfwx3Ej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FsIEHIFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aNIlsdWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qmcIv0ir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DZ8dJNxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bc0cJU9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AaqRhzIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_p5V7uuEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oNFFrEaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Nmvn94g7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_RdGJyXmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_OLBoYshR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JEBfkPFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5wf7oZnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B17Oyc0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OJPKJhhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EVYZ8ZjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1l58Pcfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_XMjmXHm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gLo0u6O8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0ukmoNvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zNcW3vl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SrxYqqcB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tPtkYzO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Ar597HbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jYreV6Nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k3FzVlSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UurXqLbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WzGYIXTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XOITFC0I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uAjWjapI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nHGo37Wf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y8Hxqdar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wV3t59F2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IhkUBnFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gviRA9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p9OIID6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ofgynSIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_q0B4f79H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_B90KveZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lVJ9tmMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DU6aoz8K_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_IUngunOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LGD1S3a7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3S7IXUvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WKdxGRUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G6q0uASZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OmVy5m31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qtNgyXwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rq4JiZxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_8Q5xh1TS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mtscEtg5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bdyhR0Df_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VwCYrC2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pBTWEHDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BSjs2KJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_PlP7xxbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oVlkwZw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vMr4Jxwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OTgPABbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yUrPyGYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TUQiUZqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TDGjgmkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bVEN6Pwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NOUFajqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LJqbV0if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SGeWmZAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQvCb5SR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vCwd662Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1w5qHdo8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_03vqUSHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YFwW1sjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V6P1Nw4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TIYvSgls_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_rh1J81OQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_P5M6zS8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QLoY1Pt3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdMZG3dV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gSb8NUba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OLjBrGyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuXLmmJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yzOPMrjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_RcjBGe2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cW4rDmAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4fkXku1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ipge0nuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XxX8RSAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_selS0FLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ac5G6h9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E4xhRiJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qkqd49ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6kifoick_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_92XXtsen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cZw2VJI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dQdKkoiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bPChFr66_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WVq2n2OX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KfEWm9h9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_04BmFBi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JUrswIRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qQNWlxo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FCrkW78h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oRASUuQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_9Ilmfz90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JOc4gUNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8D3SHrtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7jlOOc03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qan38BFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_juuRPnwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IpSCqJ5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZlbOL0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwCBuAEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cq4zGKj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7AzBkjGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fDu8Ryql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GOXGzsdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qxq8lasf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9zcZ3mDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S6BYtBkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G0kpSjEf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BnAPBRL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vfKGVquy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hsop4NoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kna4FNWj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tuHkyjPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CCGsnc1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h30nkqYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zHOfa4wd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_imaFQ8Oo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MJgud4Sm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VtCKTnWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ulw8tL6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uE2Ts6vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MHBxAdFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rBN2voW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XK62Ipev_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JDiFOI54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wndDZfeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2tidil4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wHvDeleR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lKopx8YH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zzsmPbGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xfwsKrOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v0SIVsUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EkUbKgAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YMTWA6Vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W8PI1Ks0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mVyZ3KP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jnjAcD9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ra39Mn9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BiW0UOUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kyXu3HCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JhB1ScGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_g84JUwSd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8dknvqYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yb4OcyDe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_JolMM7nZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5zsnKKWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yNFPWypD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h9153C9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fuDnuwSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TBp9U4cJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6levzRH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wX7VqTmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_a4iWH7aM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gl70eWFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZbGQkUVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2qlQJWGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_26kMPbsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_r8t5lnge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ToDGYBaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8lewcrIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hDyyBkyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JLDC9Jbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xVob4JU0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fTgcucfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iPWYNRtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DCHn5tRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R4yCBlc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_to6UPzCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CdUVFIGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cg8q8E2K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dhadvgLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4sJ5IvBy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_7jOTPdgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ynS8j7NF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u2FDj0hG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_DqJmbyG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PSQHFZnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dx8pN6IR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XMtppSrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AewI9EU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y0m9Hj0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ehlo9gKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TdjB8y2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WdxqdmeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uMjWJIUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iumINCfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t1ZoaNIj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zCFhCFmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ro31Ito7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xC19vK2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rM1iAzOU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vJcHjdy6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_IMcvW2dx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JBFW89HD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9YqV6HSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eDTE1G4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fYI8s6VM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cgDwXHic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5KeX9ckr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bKuMbYZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dhHXNhqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sCyh0rC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6DCJQn3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sRRX6sHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sCmttUiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xbmerv5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sg2vsWzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M6Vdx01L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2w7B95I6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tPMDQGzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYRQ5bNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rnPRTrev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XP5f9QlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x8h1MNof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A8DK0CS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bHtV8W8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CDLtUnpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HDazuGjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lr4frcNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YoX5Bi6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iJsA2L5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iFy8oZvb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_legh2Dm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qUZ3J7cI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iIWEqnJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_krW82gcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Pla3vfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q93rku7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NpRO8Bgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xBjcimm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c0ISHmmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EDVUvA64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XSihFHz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3bpk0Wdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ckoLO05k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1ER1tpx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y2qdH11F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kdtccGXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_deo0CsBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b8XUaSwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KsKRP83f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jk5cOU1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Eqy0F4yQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_njw3luQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lfZXyzi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s7kB6mPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sxXjg6k2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8S6LTRx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QV6ahpu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K2Q4k9ix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aj55TDHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bEBGX5CK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z7Y46nbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rqA4FXQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_f53lGHMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_71cf7esd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n8n97rEU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yWtioPCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kkLlZuTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M2eAU6oA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mw3Yee1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iuORahhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dJf2VUwt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3wqtwbAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3YUFAfL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Od6oYqC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4yXeuyzc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v9ppyIbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_liyVNj4A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nQEK0weP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ui8H2ZCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5xpfIfpS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OxVh5UYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HHqhJnin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_svkkmqQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_KBqMzKSc;
  SignalLine sLine_zJtUp23j;
  SignalLine sLine_qyvbQuC8;
  SignalTabhead sTabhead_sI3uoCMZ;
  SignalTabread sTabread_pJtrqzXF;
  SignalTabread sTabread_JpHslDDO;
  SignalTabhead sTabhead_rp0wlpFF;
  SignalTabread sTabread_ix3PpzZt;
  SignalTabread sTabread_Fly7dUJi;
  SignalTabwrite sTabwrite_REzBjicD;
  SignalRPole sRPole_MvbpORTq;
  SignalDel1 sDel1_BP2vBDbu;
  SignalTabread sTabread_ToDGYBaJ;
  SignalTabwrite sTabwrite_LsxhWH34;
  SignalTabread sTabread_XN3xD77l;
  SignalRPole sRPole_oZUfZ0P4;
  SignalLine sLine_CH5mHjGq;
  SignalLine sLine_AQ2mKBFw;
  SignalTabread sTabread_pf1cY1OZ;
  SignalTabread sTabread_dQGshT1h;
  SignalTabread sTabread_CGNBqTxo;
  SignalTabread sTabread_Ar597HbC;
  SignalTabread sTabread_ac5G6h9O;
  SignalTabread sTabread_PlP7xxbO;
  SignalTabwrite sTabwrite_agVDldlT;
  SignalTabwrite sTabwrite_yVHo2jC2;
  SignalTabwrite sTabwrite_8vhIuJU1;
  SignalTabwrite sTabwrite_cT1TOIgt;
  SignalTabwrite sTabwrite_Lua8jujC;
  SignalTabwrite sTabwrite_6BE9JuDb;
  SignalTabread sTabread_0NB9mQvI;
  SignalRPole sRPole_qSCUvnDo;
  SignalTabread sTabread_5zeiANgd;
  SignalRPole sRPole_fypMuiNt;
  SignalTabread sTabread_KxdxpacY;
  SignalRPole sRPole_mHxzWSA3;
  SignalTabwrite sTabwrite_Be2e7QTJ;
  SignalTabwrite sTabwrite_3i2N9rQ8;
  SignalTabwrite sTabwrite_ndgyGCyS;
  SignalTabwrite sTabwrite_r9yAMZTg;
  SignalLine sLine_7tzfj00M;
  ControlVar cVar_jxc8nh7e;
  ControlVar cVar_eWrLPeWY;
  ControlPack cPack_ZkA0lV1C;
  ControlBinop cBinop_asYb3MXJ;
  ControlVar cVar_cSc1V3Cd;
  ControlPack cPack_jse1GMo3;
  ControlVar cVar_TaxVq1PI;
  ControlVar cVar_frl0xbDU;
  ControlDelay cDelay_LZlB2H7V;
  ControlDelay cDelay_LfBMXglU;
  ControlBinop cBinop_YfkBLIOQ;
  HvTable hTable_FFPwH9Q1;
  ControlBinop cBinop_3F1L2XQ7;
  ControlVar cVar_ej5YC4v1;
  ControlBinop cBinop_ZnYXelYS;
  ControlBinop cBinop_M3gzjeWU;
  SignalVarf sVarf_0bbw6Ji8;
  SignalVarf sVarf_QHaWdY5K;
  SignalVarf sVarf_33hpWEM1;
  ControlVar cVar_PlTVLrIv;
  ControlBinop cBinop_86xO1gGa;
  ControlBinop cBinop_9Ha4p90s;
  SignalVarf sVarf_P6LFPaT4;
  SignalVarf sVarf_I65smqJg;
  SignalVarf sVarf_OrdTojmI;
  ControlBinop cBinop_57Lwqf7G;
  ControlBinop cBinop_wFV8jId0;
  ControlBinop cBinop_ooIrhKXZ;
  ControlBinop cBinop_T5ZPYz3t;
  ControlBinop cBinop_7angG404;
  ControlBinop cBinop_8qdNbeAS;
  ControlBinop cBinop_qC40sKsS;
  ControlBinop cBinop_sDCewse9;
  ControlBinop cBinop_9OkeQxW3;
  SignalVarf sVarf_OMh96Snw;
  ControlVar cVar_HkSnukSe;
  ControlBinop cBinop_HaMKtHdy;
  ControlBinop cBinop_NcgH2cIA;
  ControlBinop cBinop_e1izAppf;
  ControlBinop cBinop_kj6SjeF3;
  ControlBinop cBinop_56Q0L3QD;
  ControlBinop cBinop_4clHKkyM;
  ControlBinop cBinop_HfyiHprn;
  SignalVarf sVarf_xUIGOJNt;
  ControlBinop cBinop_LcUZUHUT;
  ControlRandom cRandom_5AhXQpEE;
  ControlSlice cSlice_p3JYqO4r;
  ControlDelay cDelay_TQ6wrOc9;
  ControlVar cVar_Gcjymb3k;
  ControlBinop cBinop_2JMrrT7g;
  ControlBinop cBinop_cs94M7gY;
  ControlBinop cBinop_Sf3OnOiC;
  ControlTabhead cTabhead_XuFtM1H0;
  ControlVar cVar_OqSeOw4v;
  ControlDelay cDelay_32QZ3iKI;
  ControlDelay cDelay_rRMlV8NM;
  ControlBinop cBinop_ZSDyEfRo;
  ControlBinop cBinop_Pd1klUq3;
  ControlBinop cBinop_MCuSNwug;
  ControlBinop cBinop_iRTS7mSa;
  ControlBinop cBinop_H6IrvDWe;
  ControlBinop cBinop_bt7OvsCy;
  ControlTabhead cTabhead_sU5zvxGK;
  ControlVar cVar_1mWlg4ka;
  ControlDelay cDelay_Kp9lX2WD;
  ControlDelay cDelay_ubNnlMNf;
  ControlBinop cBinop_uw7bQCJ5;
  ControlBinop cBinop_YVKQG90N;
  ControlBinop cBinop_4006Cx5d;
  ControlBinop cBinop_4mQYdruj;
  ControlBinop cBinop_0YpmNAyW;
  ControlBinop cBinop_ZqqZ2KE8;
  ControlTabhead cTabhead_k4oIYlfJ;
  ControlVar cVar_ApEgP0Xq;
  ControlDelay cDelay_RPhAdHnE;
  ControlDelay cDelay_5RieiJ5e;
  ControlBinop cBinop_twLn03Sz;
  ControlBinop cBinop_JoDXIAax;
  ControlBinop cBinop_nPLjJZRc;
  ControlBinop cBinop_tcxj0JEZ;
  ControlBinop cBinop_WoGmfHpP;
  ControlBinop cBinop_QqH8bE7t;
  ControlTabhead cTabhead_qF7ovFDX;
  ControlVar cVar_gOhnUmKF;
  ControlDelay cDelay_y3gYDxvQ;
  ControlDelay cDelay_GYDFTj0o;
  ControlBinop cBinop_aduDC76K;
  ControlBinop cBinop_8HAv3pmo;
  ControlBinop cBinop_ZzO2tBfu;
  ControlBinop cBinop_u2OihzGt;
  ControlBinop cBinop_kJAkPPTZ;
  ControlBinop cBinop_35epTNIU;
  ControlDelay cDelay_63h73XxR;
  ControlDelay cDelay_hHuJWzNA;
  ControlBinop cBinop_nH1rlWzX;
  HvTable hTable_EKayMEtr;
  ControlBinop cBinop_nVOkl3X9;
  ControlDelay cDelay_iHWbdVcY;
  ControlDelay cDelay_DvaiUoy4;
  ControlBinop cBinop_QKI0sWNG;
  HvTable hTable_EdKgNVIX;
  ControlBinop cBinop_Sjxga2pX;
  ControlDelay cDelay_2F8zWUy1;
  ControlDelay cDelay_eBVMARli;
  ControlBinop cBinop_Oem6U7hE;
  HvTable hTable_tqKcplW8;
  ControlBinop cBinop_gkgmWr5D;
  ControlDelay cDelay_xGOCK1Wy;
  ControlDelay cDelay_2ZwEnOSj;
  ControlBinop cBinop_ph6LtCgG;
  HvTable hTable_eyu9PmsV;
  ControlBinop cBinop_YthDV6EY;
  ControlPack cPack_ZB5AFMFR;
  ControlPack cPack_F9o998ik;
  ControlBinop cBinop_5BLqaItw;
  ControlBinop cBinop_2O2AVR80;
  ControlVar cVar_c7TnuvkD;
  ControlBinop cBinop_2sWzRYI0;
  ControlBinop cBinop_t4wTJIJo;
  SignalVarf sVarf_0yuIjbUX;
  ControlBinop cBinop_Vm8qKQZW;
  ControlBinop cBinop_qQyBTeQL;
  ControlBinop cBinop_bgIuO2JX;
  SignalVarf sVarf_wpYfVd94;
  ControlVar cVar_LhTRrR5J;
  ControlVar cVar_GmG7Z0A3;
  ControlVar cVar_CpIYPq7e;
  ControlVar cVar_atxWBLLw;
  ControlIf cIf_rDbqZAtp;
  ControlBinop cBinop_rfH4OddQ;
  ControlBinop cBinop_zoTrgGID;
  ControlBinop cBinop_ltNKIPH3;
  ControlDelay cDelay_yv9eZCBX;
  ControlDelay cDelay_GCnptN1u;
  ControlBinop cBinop_qBrHPAM8;
  HvTable hTable_txzS0m3F;
  ControlBinop cBinop_CTqtmFRQ;
  ControlTabhead cTabhead_vtr7MPsj;
  ControlVar cVar_sCYjb2Hl;
  ControlDelay cDelay_CYjmI4Oz;
  ControlDelay cDelay_91yk2Psw;
  ControlBinop cBinop_seQnfdqB;
  ControlBinop cBinop_bReImFcG;
  ControlBinop cBinop_aJF8A82M;
  ControlBinop cBinop_Pb2EKpY2;
  ControlBinop cBinop_OkMxRfdk;
  ControlBinop cBinop_3ZN4CapC;
  ControlDelay cDelay_Ek5hffi9;
  ControlDelay cDelay_70elUr3s;
  ControlBinop cBinop_FLWaBFz7;
  HvTable hTable_67dsIc73;
  ControlBinop cBinop_9ZYRnMHM;
  ControlTabhead cTabhead_Cbu2a9jP;
  ControlVar cVar_sGoJGP5L;
  ControlDelay cDelay_BuGzP4a9;
  ControlDelay cDelay_zyJpQ0al;
  ControlBinop cBinop_9CizaDQB;
  ControlBinop cBinop_bALyCEyw;
  ControlBinop cBinop_fCecfaUP;
  ControlBinop cBinop_cN5IfL6m;
  ControlBinop cBinop_3ITuL5M9;
  ControlBinop cBinop_Yn3XTgvL;
  ControlDelay cDelay_toAXgDXl;
  ControlDelay cDelay_qxzSf9pe;
  ControlBinop cBinop_djWOTh2R;
  HvTable hTable_sqj6Gv21;
  ControlBinop cBinop_X2Jaiumj;
  ControlTabhead cTabhead_ShQPLGxc;
  ControlVar cVar_arFAj48c;
  ControlDelay cDelay_ZLCkeDzo;
  ControlDelay cDelay_IQ5kWxsv;
  ControlBinop cBinop_uOqqeUuR;
  ControlBinop cBinop_N7ygxQpO;
  ControlBinop cBinop_QSEWGBg3;
  ControlBinop cBinop_kCfwx3Ej;
  ControlBinop cBinop_aNIlsdWm;
  ControlBinop cBinop_qmcIv0ir;
  ControlDelay cDelay_p5V7uuEd;
  ControlDelay cDelay_oNFFrEaG;
  ControlBinop cBinop_RdGJyXmD;
  HvTable hTable_OLBoYshR;
  ControlBinop cBinop_5wf7oZnm;
  ControlTabhead cTabhead_XMjmXHm8;
  ControlVar cVar_zNcW3vl4;
  ControlDelay cDelay_SrxYqqcB;
  ControlDelay cDelay_tPtkYzO2;
  ControlBinop cBinop_jYreV6Nw;
  ControlBinop cBinop_k3FzVlSR;
  ControlBinop cBinop_UurXqLbV;
  ControlBinop cBinop_y8Hxqdar;
  ControlBinop cBinop_IhkUBnFN;
  ControlBinop cBinop_2gviRA9G;
  ControlDelay cDelay_B90KveZJ;
  ControlDelay cDelay_lVJ9tmMx;
  ControlBinop cBinop_IUngunOs;
  HvTable hTable_LGD1S3a7;
  ControlBinop cBinop_WKdxGRUI;
  ControlTabhead cTabhead_8Q5xh1TS;
  ControlVar cVar_VwCYrC2v;
  ControlDelay cDelay_pBTWEHDq;
  ControlDelay cDelay_BSjs2KJg;
  ControlBinop cBinop_oVlkwZw3;
  ControlBinop cBinop_vMr4Jxwf;
  ControlBinop cBinop_OTgPABbj;
  ControlBinop cBinop_NOUFajqj;
  ControlBinop cBinop_SGeWmZAS;
  ControlBinop cBinop_oQvCb5SR;
  ControlDelay cDelay_YFwW1sjR;
  ControlDelay cDelay_V6P1Nw4b;
  ControlBinop cBinop_rh1J81OQ;
  HvTable hTable_P5M6zS8g;
  ControlBinop cBinop_gdMZG3dV;
  ControlTabhead cTabhead_RcjBGe2N;
  ControlVar cVar_Ipge0nuF;
  ControlDelay cDelay_XxX8RSAt;
  ControlDelay cDelay_selS0FLf;
  ControlBinop cBinop_E4xhRiJ1;
  ControlBinop cBinop_qkqd49ok;
  ControlBinop cBinop_6kifoick;
  ControlBinop cBinop_WVq2n2OX;
  ControlBinop cBinop_04BmFBi7;
  ControlBinop cBinop_JUrswIRx;
  ControlVar cVar_FCrkW78h;
  ControlVar cVar_oRASUuQ3;
  ControlPack cPack_9Ilmfz90;
  ControlVar cVar_JOc4gUNL;
  ControlBinop cBinop_qan38BFa;
  ControlBinop cBinop_juuRPnwb;
  SignalVarf sVarf_324nPTEl;
  ControlBinop cBinop_TZlbOL0W;
  ControlBinop cBinop_SwCBuAEI;
  ControlBinop cBinop_Cq4zGKj3;
  SignalVarf sVarf_GgRgiQ3q;
  ControlVar cVar_7AzBkjGy;
  ControlBinop cBinop_Qxq8lasf;
  ControlBinop cBinop_9zcZ3mDn;
  SignalVarf sVarf_McgoWCYH;
  ControlBinop cBinop_G0kpSjEf;
  ControlBinop cBinop_BnAPBRL9;
  ControlBinop cBinop_vfKGVquy;
  SignalVarf sVarf_o140dlFp;
  ControlVar cVar_Hsop4NoO;
  ControlBinop cBinop_CCGsnc1U;
  ControlBinop cBinop_h30nkqYo;
  SignalVarf sVarf_RPMr8mCh;
  ControlBinop cBinop_imaFQ8Oo;
  ControlBinop cBinop_MJgud4Sm;
  ControlBinop cBinop_VtCKTnWc;
  SignalVarf sVarf_FdTt7rFV;
  ControlBinop cBinop_ulw8tL6u;
  ControlBinop cBinop_MHBxAdFC;
  ControlBinop cBinop_rBN2voW7;
  ControlDelay cDelay_JDiFOI54;
  ControlVar cVar_lKopx8YH;
  ControlBinop cBinop_xfwsKrOH;
  ControlBinop cBinop_v0SIVsUi;
  ControlBinop cBinop_EkUbKgAB;
  ControlVar cVar_YMTWA6Vu;
  ControlVar cVar_W8PI1Ks0;
  ControlIf cIf_ra39Mn9U;
  ControlBinop cBinop_BiW0UOUu;
  ControlDelay cDelay_g84JUwSd;
  ControlDelay cDelay_8dknvqYF;
  ControlBinop cBinop_JolMM7nZ;
  HvTable hTable_5zsnKKWw;
  ControlBinop cBinop_h9153C9K;
  ControlTabhead cTabhead_a4iWH7aM;
  ControlVar cVar_2qlQJWGo;
  ControlDelay cDelay_26kMPbsI;
  ControlDelay cDelay_r8t5lnge;
  ControlBinop cBinop_8lewcrIg;
  ControlBinop cBinop_hDyyBkyC;
  ControlBinop cBinop_JLDC9Jbk;
  ControlBinop cBinop_R4yCBlc4;
  ControlBinop cBinop_CdUVFIGA;
  ControlBinop cBinop_Cg8q8E2K;
  ControlVar cVar_ynS8j7NF;
  ControlVar cVar_PSQHFZnF;
  ControlVar cVar_dx8pN6IR;
  ControlVar cVar_XMtppSrt;
  ControlVar cVar_AewI9EU3;
  ControlVar cVar_y0m9Hj0m;
  ControlIf cIf_WdxqdmeS;
  ControlBinop cBinop_uMjWJIUp;
  ControlVar cVar_iumINCfg;
  ControlIf cIf_ro31Ito7;
  ControlBinop cBinop_xC19vK2X;
  ControlSlice cSlice_vJcHjdy6;
  ControlSlice cSlice_IMcvW2dx;
  ControlVar cVar_JBFW89HD;
  ControlIf cIf_9YqV6HSo;
  ControlBinop cBinop_cgDwXHic;
  ControlIf cIf_dhHXNhqU;
  ControlIf cIf_sCyh0rC1;
  ControlIf cIf_6DCJQn3p;
  ControlIf cIf_sRRX6sHh;
  ControlIf cIf_sCmttUiq;
  SignalVarf sVarf_8DlmzqPN;
  ControlBinop cBinop_tPMDQGzH;
  ControlBinop cBinop_iYRQ5bNK;
  ControlBinop cBinop_XP5f9QlP;
  ControlBinop cBinop_x8h1MNof;
  SignalVarf sVarf_LbpWFsSl;
  ControlBinop cBinop_bHtV8W8t;
  ControlBinop cBinop_CDLtUnpj;
  SignalVarf sVarf_o0Y5WOuF;
  SignalVarf sVarf_V4qjl42r;
  ControlBinop cBinop_iFy8oZvb;
  ControlBinop cBinop_legh2Dm1;
  ControlBinop cBinop_qUZ3J7cI;
  ControlBinop cBinop_iIWEqnJB;
  ControlBinop cBinop_6Pla3vfm;
  ControlBinop cBinop_Q93rku7x;
  ControlBinop cBinop_NpRO8Bgi;
  ControlBinop cBinop_xBjcimm3;
  ControlBinop cBinop_EDVUvA64;
  ControlBinop cBinop_XSihFHz7;
  ControlBinop cBinop_3bpk0Wdl;
  ControlBinop cBinop_lfZXyzi2;
  ControlBinop cBinop_s7kB6mPh;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
