/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_KBqMzKSc, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_zJtUp23j);
  numBytes += sLine_init(&sLine_qyvbQuC8);
  numBytes += sTabhead_init(&sTabhead_sI3uoCMZ, &hTable_FFPwH9Q1);
  numBytes += sTabread_init(&sTabread_pJtrqzXF, &hTable_FFPwH9Q1, false);
  numBytes += sTabread_init(&sTabread_JpHslDDO, &hTable_FFPwH9Q1, false);
  numBytes += sTabhead_init(&sTabhead_rp0wlpFF, &hTable_FFPwH9Q1);
  numBytes += sTabread_init(&sTabread_ix3PpzZt, &hTable_FFPwH9Q1, false);
  numBytes += sTabread_init(&sTabread_Fly7dUJi, &hTable_FFPwH9Q1, false);
  numBytes += sTabwrite_init(&sTabwrite_REzBjicD, &hTable_FFPwH9Q1);
  numBytes += sRPole_init(&sRPole_MvbpORTq);
  numBytes += sDel1_init(&sDel1_BP2vBDbu);
  numBytes += sTabread_init(&sTabread_ToDGYBaJ, &hTable_5zsnKKWw, true);
  numBytes += sTabwrite_init(&sTabwrite_LsxhWH34, &hTable_5zsnKKWw);
  numBytes += sTabread_init(&sTabread_XN3xD77l, &hTable_EKayMEtr, true);
  numBytes += sRPole_init(&sRPole_oZUfZ0P4);
  numBytes += sLine_init(&sLine_CH5mHjGq);
  numBytes += sLine_init(&sLine_AQ2mKBFw);
  numBytes += sTabread_init(&sTabread_pf1cY1OZ, &hTable_txzS0m3F, true);
  numBytes += sTabread_init(&sTabread_dQGshT1h, &hTable_67dsIc73, true);
  numBytes += sTabread_init(&sTabread_CGNBqTxo, &hTable_sqj6Gv21, true);
  numBytes += sTabread_init(&sTabread_Ar597HbC, &hTable_OLBoYshR, true);
  numBytes += sTabread_init(&sTabread_ac5G6h9O, &hTable_P5M6zS8g, true);
  numBytes += sTabread_init(&sTabread_PlP7xxbO, &hTable_LGD1S3a7, true);
  numBytes += sTabwrite_init(&sTabwrite_agVDldlT, &hTable_txzS0m3F);
  numBytes += sTabwrite_init(&sTabwrite_yVHo2jC2, &hTable_67dsIc73);
  numBytes += sTabwrite_init(&sTabwrite_8vhIuJU1, &hTable_sqj6Gv21);
  numBytes += sTabwrite_init(&sTabwrite_cT1TOIgt, &hTable_OLBoYshR);
  numBytes += sTabwrite_init(&sTabwrite_Lua8jujC, &hTable_LGD1S3a7);
  numBytes += sTabwrite_init(&sTabwrite_6BE9JuDb, &hTable_P5M6zS8g);
  numBytes += sTabread_init(&sTabread_0NB9mQvI, &hTable_EdKgNVIX, true);
  numBytes += sRPole_init(&sRPole_qSCUvnDo);
  numBytes += sTabread_init(&sTabread_5zeiANgd, &hTable_tqKcplW8, true);
  numBytes += sRPole_init(&sRPole_fypMuiNt);
  numBytes += sTabread_init(&sTabread_KxdxpacY, &hTable_eyu9PmsV, true);
  numBytes += sRPole_init(&sRPole_mHxzWSA3);
  numBytes += sTabwrite_init(&sTabwrite_Be2e7QTJ, &hTable_EKayMEtr);
  numBytes += sTabwrite_init(&sTabwrite_3i2N9rQ8, &hTable_EdKgNVIX);
  numBytes += sTabwrite_init(&sTabwrite_ndgyGCyS, &hTable_tqKcplW8);
  numBytes += sTabwrite_init(&sTabwrite_r9yAMZTg, &hTable_eyu9PmsV);
  numBytes += sLine_init(&sLine_7tzfj00M);
  numBytes += cVar_init_f(&cVar_jxc8nh7e, 0.0f);
  numBytes += cVar_init_f(&cVar_eWrLPeWY, 0.0f);
  numBytes += cPack_init(&cPack_ZkA0lV1C, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_cSc1V3Cd, 0.0f);
  numBytes += cPack_init(&cPack_jse1GMo3, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_TaxVq1PI, 0.0f);
  numBytes += cVar_init_f(&cVar_frl0xbDU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LZlB2H7V, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LfBMXglU, 0.0f);
  numBytes += hTable_init(&hTable_FFPwH9Q1, 256);
  numBytes += cVar_init_s(&cVar_ej5YC4v1, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_0bbw6Ji8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QHaWdY5K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_33hpWEM1, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_PlTVLrIv, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_P6LFPaT4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I65smqJg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OrdTojmI, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_57Lwqf7G, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_OMh96Snw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HkSnukSe, 0.0f);
  numBytes += cBinop_init(&cBinop_HfyiHprn, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_xUIGOJNt, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_5AhXQpEE, 1247018057);
  numBytes += cSlice_init(&cSlice_p3JYqO4r, 1, 1);
  numBytes += cDelay_init(this, &cDelay_TQ6wrOc9, 0.0f);
  numBytes += cVar_init_f(&cVar_Gcjymb3k, 5.0f);
  numBytes += cBinop_init(&cBinop_Sf3OnOiC, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_XuFtM1H0, &hTable_EKayMEtr);
  numBytes += cVar_init_s(&cVar_OqSeOw4v, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_32QZ3iKI, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_rRMlV8NM, 0.0f);
  numBytes += cBinop_init(&cBinop_ZSDyEfRo, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_MCuSNwug, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_iRTS7mSa, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bt7OvsCy, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_sU5zvxGK, &hTable_EdKgNVIX);
  numBytes += cVar_init_s(&cVar_1mWlg4ka, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_Kp9lX2WD, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_ubNnlMNf, 0.0f);
  numBytes += cBinop_init(&cBinop_uw7bQCJ5, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_4006Cx5d, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4mQYdruj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ZqqZ2KE8, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_k4oIYlfJ, &hTable_tqKcplW8);
  numBytes += cVar_init_s(&cVar_ApEgP0Xq, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_RPhAdHnE, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_5RieiJ5e, 0.0f);
  numBytes += cBinop_init(&cBinop_twLn03Sz, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_nPLjJZRc, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tcxj0JEZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QqH8bE7t, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_qF7ovFDX, &hTable_eyu9PmsV);
  numBytes += cVar_init_s(&cVar_gOhnUmKF, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_y3gYDxvQ, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_GYDFTj0o, 0.0f);
  numBytes += cBinop_init(&cBinop_aduDC76K, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_ZzO2tBfu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_u2OihzGt, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_35epTNIU, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_63h73XxR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hHuJWzNA, 0.0f);
  numBytes += hTable_init(&hTable_EKayMEtr, 256);
  numBytes += cDelay_init(this, &cDelay_iHWbdVcY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DvaiUoy4, 0.0f);
  numBytes += hTable_init(&hTable_EdKgNVIX, 256);
  numBytes += cDelay_init(this, &cDelay_2F8zWUy1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_eBVMARli, 0.0f);
  numBytes += hTable_init(&hTable_tqKcplW8, 256);
  numBytes += cDelay_init(this, &cDelay_xGOCK1Wy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2ZwEnOSj, 0.0f);
  numBytes += hTable_init(&hTable_eyu9PmsV, 256);
  numBytes += cPack_init(&cPack_ZB5AFMFR, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_F9o998ik, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_c7TnuvkD, 22050.0f);
  numBytes += cBinop_init(&cBinop_2sWzRYI0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0yuIjbUX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wpYfVd94, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_LhTRrR5J, 0.0f);
  numBytes += cVar_init_f(&cVar_GmG7Z0A3, 0.0f);
  numBytes += cVar_init_f(&cVar_CpIYPq7e, 0.0f);
  numBytes += cVar_init_f(&cVar_atxWBLLw, 0.0f);
  numBytes += cIf_init(&cIf_rDbqZAtp, false);
  numBytes += cDelay_init(this, &cDelay_yv9eZCBX, 0.0f);
  numBytes += cDelay_init(this, &cDelay_GCnptN1u, 0.0f);
  numBytes += hTable_init(&hTable_txzS0m3F, 256);
  numBytes += cTabhead_init(&cTabhead_vtr7MPsj, &hTable_txzS0m3F);
  numBytes += cVar_init_s(&cVar_sCYjb2Hl, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_CYjmI4Oz, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_91yk2Psw, 0.0f);
  numBytes += cBinop_init(&cBinop_seQnfdqB, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_aJF8A82M, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Pb2EKpY2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_3ZN4CapC, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Ek5hffi9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_70elUr3s, 0.0f);
  numBytes += hTable_init(&hTable_67dsIc73, 256);
  numBytes += cTabhead_init(&cTabhead_Cbu2a9jP, &hTable_67dsIc73);
  numBytes += cVar_init_s(&cVar_sGoJGP5L, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_BuGzP4a9, 25.796f);
  numBytes += cDelay_init(this, &cDelay_zyJpQ0al, 0.0f);
  numBytes += cBinop_init(&cBinop_9CizaDQB, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_fCecfaUP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_cN5IfL6m, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Yn3XTgvL, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_toAXgDXl, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qxzSf9pe, 0.0f);
  numBytes += hTable_init(&hTable_sqj6Gv21, 256);
  numBytes += cTabhead_init(&cTabhead_ShQPLGxc, &hTable_sqj6Gv21);
  numBytes += cVar_init_s(&cVar_arFAj48c, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_ZLCkeDzo, 19.392f);
  numBytes += cDelay_init(this, &cDelay_IQ5kWxsv, 0.0f);
  numBytes += cBinop_init(&cBinop_uOqqeUuR, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_QSEWGBg3, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kCfwx3Ej, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_qmcIv0ir, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_p5V7uuEd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oNFFrEaG, 0.0f);
  numBytes += hTable_init(&hTable_OLBoYshR, 256);
  numBytes += cTabhead_init(&cTabhead_XMjmXHm8, &hTable_OLBoYshR);
  numBytes += cVar_init_s(&cVar_zNcW3vl4, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_SrxYqqcB, 16.364f);
  numBytes += cDelay_init(this, &cDelay_tPtkYzO2, 0.0f);
  numBytes += cBinop_init(&cBinop_jYreV6Nw, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_UurXqLbV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_y8Hxqdar, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2gviRA9G, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_B90KveZJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lVJ9tmMx, 0.0f);
  numBytes += hTable_init(&hTable_LGD1S3a7, 256);
  numBytes += cTabhead_init(&cTabhead_8Q5xh1TS, &hTable_LGD1S3a7);
  numBytes += cVar_init_s(&cVar_VwCYrC2v, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_pBTWEHDq, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_BSjs2KJg, 0.0f);
  numBytes += cBinop_init(&cBinop_oVlkwZw3, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_OTgPABbj, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NOUFajqj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_oQvCb5SR, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_YFwW1sjR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_V6P1Nw4b, 0.0f);
  numBytes += hTable_init(&hTable_P5M6zS8g, 256);
  numBytes += cTabhead_init(&cTabhead_RcjBGe2N, &hTable_P5M6zS8g);
  numBytes += cVar_init_s(&cVar_Ipge0nuF, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_XxX8RSAt, 7.645f);
  numBytes += cDelay_init(this, &cDelay_selS0FLf, 0.0f);
  numBytes += cBinop_init(&cBinop_E4xhRiJ1, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_6kifoick, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WVq2n2OX, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JUrswIRx, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_FCrkW78h, 0.0f);
  numBytes += cVar_init_f(&cVar_oRASUuQ3, 0.0f);
  numBytes += cPack_init(&cPack_9Ilmfz90, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_JOc4gUNL, 22050.0f);
  numBytes += cBinop_init(&cBinop_qan38BFa, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_324nPTEl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GgRgiQ3q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7AzBkjGy, 22050.0f);
  numBytes += cBinop_init(&cBinop_Qxq8lasf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_McgoWCYH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o140dlFp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Hsop4NoO, 22050.0f);
  numBytes += cBinop_init(&cBinop_CCGsnc1U, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RPMr8mCh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FdTt7rFV, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_JDiFOI54, 0.0f);
  numBytes += cVar_init_f(&cVar_lKopx8YH, 1000.0f);
  numBytes += cBinop_init(&cBinop_EkUbKgAB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YMTWA6Vu, 0.0f);
  numBytes += cVar_init_f(&cVar_W8PI1Ks0, 0.0f);
  numBytes += cIf_init(&cIf_ra39Mn9U, false);
  numBytes += cDelay_init(this, &cDelay_g84JUwSd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8dknvqYF, 0.0f);
  numBytes += hTable_init(&hTable_5zsnKKWw, 256);
  numBytes += cTabhead_init(&cTabhead_a4iWH7aM, &hTable_5zsnKKWw);
  numBytes += cVar_init_s(&cVar_2qlQJWGo, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_26kMPbsI, 150.0f);
  numBytes += cDelay_init(this, &cDelay_r8t5lnge, 0.0f);
  numBytes += cBinop_init(&cBinop_8lewcrIg, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_JLDC9Jbk, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_R4yCBlc4, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Cg8q8E2K, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_ynS8j7NF, 0.0f);
  numBytes += cVar_init_f(&cVar_PSQHFZnF, 0.0f);
  numBytes += cVar_init_f(&cVar_dx8pN6IR, 0.0f);
  numBytes += cVar_init_f(&cVar_XMtppSrt, 0.0f);
  numBytes += cVar_init_f(&cVar_AewI9EU3, 0.0f);
  numBytes += cVar_init_f(&cVar_y0m9Hj0m, 0.0f);
  numBytes += cIf_init(&cIf_WdxqdmeS, false);
  numBytes += cVar_init_f(&cVar_iumINCfg, 0.0f);
  numBytes += cIf_init(&cIf_ro31Ito7, false);
  numBytes += cSlice_init(&cSlice_vJcHjdy6, 1, -1);
  numBytes += cSlice_init(&cSlice_IMcvW2dx, 1, -1);
  numBytes += cVar_init_f(&cVar_JBFW89HD, 0.0f);
  numBytes += cIf_init(&cIf_9YqV6HSo, false);
  numBytes += cBinop_init(&cBinop_cgDwXHic, 0.0f); // __neq
  numBytes += cIf_init(&cIf_dhHXNhqU, false);
  numBytes += cIf_init(&cIf_sCyh0rC1, false);
  numBytes += cIf_init(&cIf_6DCJQn3p, false);
  numBytes += cIf_init(&cIf_sRRX6sHh, true);
  numBytes += cIf_init(&cIf_sCmttUiq, false);
  numBytes += sVarf_init(&sVarf_8DlmzqPN, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_XP5f9QlP, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_LbpWFsSl, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_bHtV8W8t, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CDLtUnpj, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_o0Y5WOuF, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V4qjl42r, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_legh2Dm1, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_EDVUvA64, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XSihFHz7, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_3bpk0Wdl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_lfZXyzi2, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_s7kB6mPh, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_ZkA0lV1C);
  cPack_free(&cPack_jse1GMo3);
  hTable_free(&hTable_FFPwH9Q1);
  hTable_free(&hTable_EKayMEtr);
  hTable_free(&hTable_EdKgNVIX);
  hTable_free(&hTable_tqKcplW8);
  hTable_free(&hTable_eyu9PmsV);
  cPack_free(&cPack_ZB5AFMFR);
  cPack_free(&cPack_F9o998ik);
  hTable_free(&hTable_txzS0m3F);
  hTable_free(&hTable_67dsIc73);
  hTable_free(&hTable_sqj6Gv21);
  hTable_free(&hTable_OLBoYshR);
  hTable_free(&hTable_LGD1S3a7);
  hTable_free(&hTable_P5M6zS8g);
  cPack_free(&cPack_9Ilmfz90);
  hTable_free(&hTable_5zsnKKWw);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_FFPwH9Q1; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_EKayMEtr; // del-1052-del1
    case 0xA2AC524D: return &hTable_EdKgNVIX; // del-1052-del2
    case 0xE36A35B: return &hTable_tqKcplW8; // del-1052-del3
    case 0x48CE0509: return &hTable_eyu9PmsV; // del-1052-del4
    case 0xE34D6E72: return &hTable_txzS0m3F; // del-1052-ref1
    case 0x6A1027AB: return &hTable_67dsIc73; // del-1052-ref2
    case 0xA37C6D49: return &hTable_sqj6Gv21; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_OLBoYshR; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_LGD1S3a7; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_P5M6zS8g; // del-1052-ref5
    case 0xED65564F: return &hTable_5zsnKKWw; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z7Y46nbP_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_71cf7esd_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f53lGHMe_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_svkkmqQy_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rqA4FXQe_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n8n97rEU_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yWtioPCx_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iuORahhM_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mw3Yee1u_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dJf2VUwt_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3wqtwbAe_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kkLlZuTy_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M2eAU6oA_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5xpfIfpS_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ui8H2ZCU_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQEK0weP_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_liyVNj4A_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HHqhJnin_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OxVh5UYP_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Od6oYqC6_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3YUFAfL3_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v9ppyIbx_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4yXeuyzc_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bEBGX5CK_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_jxc8nh7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_T5ZPYz3t_sendMessage);
}

void Heavy_ChaffVerb::cVar_eWrLPeWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qC40sKsS_sendMessage);
}

void Heavy_ChaffVerb::cPack_ZkA0lV1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_zJtUp23j, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_ugCLphGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cSc1V3Cd, 0, m, &cVar_cSc1V3Cd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_asYb3MXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_ugCLphGV_sendMessage);
}

void Heavy_ChaffVerb::cVar_cSc1V3Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ooIrhKXZ_sendMessage);
}

void Heavy_ChaffVerb::cPack_jse1GMo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_qyvbQuC8, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_TaxVq1PI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_8qdNbeAS_sendMessage);
}

void Heavy_ChaffVerb::cVar_frl0xbDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_KBqMzKSc, 0, m);
}

void Heavy_ChaffVerb::cMsg_5JlbNHoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Oz5cuyd8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Oz5cuyd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3F1L2XQ7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LZlB2H7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LZlB2H7V, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LfBMXglU, 0, m, &cDelay_LfBMXglU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LZlB2H7V, 0, m, &cDelay_LZlB2H7V_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_REzBjicD, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_LfBMXglU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LfBMXglU, m);
  cMsg_zd9UOrLx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wt9lOsQo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Lm5wwypc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_YfkBLIOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l5wdSUCi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_FFPwH9Q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zV6aIvSQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LZlB2H7V, 2, m, &cDelay_LZlB2H7V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OTxvFpgS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l5wdSUCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FFPwH9Q1, 0, m, &hTable_FFPwH9Q1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3F1L2XQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_YfkBLIOQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zd9UOrLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FFPwH9Q1, 0, m, &hTable_FFPwH9Q1_sendMessage);
}

void Heavy_ChaffVerb::cCast_OTxvFpgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LZlB2H7V, 0, m, &cDelay_LZlB2H7V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zV6aIvSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_LfBMXglU, 2, m, &cDelay_LfBMXglU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Lm5wwypc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_REzBjicD, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_ofzQlBi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r0O628DP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r0O628DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZnYXelYS_sendMessage);
}

void Heavy_ChaffVerb::cVar_ej5YC4v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5DtrZ7hy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_pwukIqfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_M3gzjeWU_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0bbw6Ji8, m);
}

void Heavy_ChaffVerb::cBinop_ZnYXelYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QHaWdY5K, m);
}

void Heavy_ChaffVerb::cMsg_5DtrZ7hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pwukIqfi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M3gzjeWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_33hpWEM1, m);
}

void Heavy_ChaffVerb::cMsg_YSlGfycc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1Fr9IBa0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1Fr9IBa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_86xO1gGa_sendMessage);
}

void Heavy_ChaffVerb::cVar_PlTVLrIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q83h6iut_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_yTkPRrnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9Ha4p90s_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_P6LFPaT4, m);
}

void Heavy_ChaffVerb::cBinop_86xO1gGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I65smqJg, m);
}

void Heavy_ChaffVerb::cMsg_q83h6iut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yTkPRrnR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9Ha4p90s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OrdTojmI, m);
}

void Heavy_ChaffVerb::cBinop_57Lwqf7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_frl0xbDU, 0, m, &cVar_frl0xbDU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wFV8jId0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6VKz2GLn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ftr716nN_sendMessage);
}

void Heavy_ChaffVerb::cCast_ftr716nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57Lwqf7G, HV_BINOP_DIVIDE, 0, m, &cBinop_57Lwqf7G_sendMessage);
}

void Heavy_ChaffVerb::cCast_6VKz2GLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57Lwqf7G, HV_BINOP_DIVIDE, 1, m, &cBinop_57Lwqf7G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ooIrhKXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7angG404_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T5ZPYz3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_asYb3MXJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7angG404_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57Lwqf7G, HV_BINOP_DIVIDE, 0, m, &cBinop_57Lwqf7G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8qdNbeAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_jse1GMo3, 0, m, &cPack_jse1GMo3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qC40sKsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_wFV8jId0_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_ZkA0lV1C, 0, m, &cPack_ZkA0lV1C_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Y1bQi8LR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCyh0rC1, 0, m, &cIf_sCyh0rC1_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_IfC2YEte_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mYVGVubI_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FxTawaSx_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uVFhIOxI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_mYVGVubI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6Vdx01L_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_FxTawaSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sg2vsWzX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_uVFhIOxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A8DK0CS9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_sDCewse9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9OkeQxW3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9OkeQxW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HaMKtHdy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kj6SjeF3_sendMessage);
}

void Heavy_ChaffVerb::cVar_HkSnukSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_56Q0L3QD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W3aSvxoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LSj7L9Ar_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LSj7L9Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfyiHprn, HV_BINOP_DIVIDE, 1, m, &cBinop_HfyiHprn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HaMKtHdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NcgH2cIA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NcgH2cIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xUIGOJNt, m);
}

void Heavy_ChaffVerb::cMsg_hnKHFRKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_e1izAppf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_e1izAppf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sDCewse9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kj6SjeF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OMh96Snw, m);
}

void Heavy_ChaffVerb::cBinop_56Q0L3QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_4clHKkyM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4clHKkyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfyiHprn, HV_BINOP_DIVIDE, 0, m, &cBinop_HfyiHprn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HfyiHprn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hnKHFRKb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_y36gZAy4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p3JYqO4r, 0, m, &cSlice_p3JYqO4r_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_5AhXQpEE, 0, m, &cRandom_5AhXQpEE_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_LcUZUHUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_y1HquUdt_sendMessage);
}

void Heavy_ChaffVerb::cUnop_y1HquUdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_iYRQ5bNK_sendMessage);
}

void Heavy_ChaffVerb::cRandom_5AhXQpEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_LcUZUHUT_sendMessage);
}

void Heavy_ChaffVerb::cSlice_p3JYqO4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_5AhXQpEE, 1, m, &cRandom_5AhXQpEE_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_SZRYyRfP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_Azwfge7i_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_Azwfge7i_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_InSFwolO_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_TQ6wrOc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TQ6wrOc9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQ6wrOc9, 0, m, &cDelay_TQ6wrOc9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YMTWA6Vu, 0, m, &cVar_YMTWA6Vu_sendMessage);
}

void Heavy_ChaffVerb::cCast_InSFwolO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Azwfge7i_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQ6wrOc9, 0, m, &cDelay_TQ6wrOc9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YMTWA6Vu, 0, m, &cVar_YMTWA6Vu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XVie5Rd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EPGeB1wd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EPGeB1wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cs94M7gY_sendMessage);
}

void Heavy_ChaffVerb::cVar_Gcjymb3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sf3OnOiC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Sf3OnOiC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Azwfge7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQ6wrOc9, 0, m, &cDelay_TQ6wrOc9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2JMrrT7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQ6wrOc9, 2, m, &cDelay_TQ6wrOc9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cs94M7gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sf3OnOiC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Sf3OnOiC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Sf3OnOiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2JMrrT7g_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_XuFtM1H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCuSNwug, HV_BINOP_SUBTRACT, 0, m, &cBinop_MCuSNwug_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8tUBw3EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s2RLzriX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_s2RLzriX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Pd1klUq3_sendMessage);
}

void Heavy_ChaffVerb::cVar_OqSeOw4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XEO7a5IL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_32QZ3iKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_32QZ3iKI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rRMlV8NM, 0, m, &cDelay_rRMlV8NM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XN3xD77l, 0, m, &sTabread_XN3xD77l_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rRMlV8NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rRMlV8NM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XN3xD77l, 0, m, &sTabread_XN3xD77l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rRMlV8NM, 0, m, &cDelay_rRMlV8NM_sendMessage);
}

void Heavy_ChaffVerb::sTabread_XN3xD77l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bt7OvsCy, HV_BINOP_SUBTRACT, 0, m, &cBinop_bt7OvsCy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ZSDyEfRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iRTS7mSa, HV_BINOP_MAX, 0, m, &cBinop_iRTS7mSa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Pd1klUq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSDyEfRo, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZSDyEfRo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MCuSNwug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SFidAGuH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XN3xD77l, 0, m, &sTabread_XN3xD77l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xLMlFkBG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zM9Wbm9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bt7OvsCy, HV_BINOP_SUBTRACT, 1, m, &cBinop_bt7OvsCy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rRMlV8NM, 2, m, &cDelay_rRMlV8NM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XEO7a5IL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zM9Wbm9F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SFidAGuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_32QZ3iKI, 0, m, &cDelay_32QZ3iKI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rRMlV8NM, 0, m, &cDelay_rRMlV8NM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qxG6eqYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_iRTS7mSa, HV_BINOP_MAX, 1, m, &cBinop_iRTS7mSa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iRTS7mSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCuSNwug, HV_BINOP_SUBTRACT, 1, m, &cBinop_MCuSNwug_sendMessage);
}

void Heavy_ChaffVerb::cCast_xLMlFkBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_32QZ3iKI, 0, m, &cDelay_32QZ3iKI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_H6IrvDWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_32QZ3iKI, 2, m, &cDelay_32QZ3iKI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bt7OvsCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_H6IrvDWe_sendMessage);
}

void Heavy_ChaffVerb::cCast_9cjTDhND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OqSeOw4v, 0, m, &cVar_OqSeOw4v_sendMessage);
  cMsg_8tUBw3EL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XuFtM1H0, 0, m, &cTabhead_XuFtM1H0_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_sU5zvxGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4006Cx5d, HV_BINOP_SUBTRACT, 0, m, &cBinop_4006Cx5d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XgwwekLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RqePczTv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RqePczTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YVKQG90N_sendMessage);
}

void Heavy_ChaffVerb::cVar_1mWlg4ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e9rdIeaw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_Kp9lX2WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Kp9lX2WD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ubNnlMNf, 0, m, &cDelay_ubNnlMNf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0NB9mQvI, 0, m, &sTabread_0NB9mQvI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ubNnlMNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ubNnlMNf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0NB9mQvI, 0, m, &sTabread_0NB9mQvI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ubNnlMNf, 0, m, &cDelay_ubNnlMNf_sendMessage);
}

void Heavy_ChaffVerb::sTabread_0NB9mQvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ZqqZ2KE8, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZqqZ2KE8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uw7bQCJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mQYdruj, HV_BINOP_MAX, 0, m, &cBinop_4mQYdruj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YVKQG90N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uw7bQCJ5, HV_BINOP_MULTIPLY, 0, m, &cBinop_uw7bQCJ5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4006Cx5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yAVkc4gl_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0NB9mQvI, 0, m, &sTabread_0NB9mQvI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_acZqYnVo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lBRhJt20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZqqZ2KE8, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZqqZ2KE8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ubNnlMNf, 2, m, &cDelay_ubNnlMNf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e9rdIeaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lBRhJt20_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yAVkc4gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kp9lX2WD, 0, m, &cDelay_Kp9lX2WD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ubNnlMNf, 0, m, &cDelay_ubNnlMNf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KwJJr6q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mQYdruj, HV_BINOP_MAX, 1, m, &cBinop_4mQYdruj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4mQYdruj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4006Cx5d, HV_BINOP_SUBTRACT, 1, m, &cBinop_4006Cx5d_sendMessage);
}

void Heavy_ChaffVerb::cCast_acZqYnVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kp9lX2WD, 0, m, &cDelay_Kp9lX2WD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0YpmNAyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kp9lX2WD, 2, m, &cDelay_Kp9lX2WD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZqqZ2KE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0YpmNAyW_sendMessage);
}

void Heavy_ChaffVerb::cCast_Yzf3Jc5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1mWlg4ka, 0, m, &cVar_1mWlg4ka_sendMessage);
  cMsg_XgwwekLO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sU5zvxGK, 0, m, &cTabhead_sU5zvxGK_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_k4oIYlfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPLjJZRc, HV_BINOP_SUBTRACT, 0, m, &cBinop_nPLjJZRc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TY6U4juR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A7NrjUfh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A7NrjUfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JoDXIAax_sendMessage);
}

void Heavy_ChaffVerb::cVar_ApEgP0Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lu0PcUik_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_RPhAdHnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RPhAdHnE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5RieiJ5e, 0, m, &cDelay_5RieiJ5e_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5zeiANgd, 0, m, &sTabread_5zeiANgd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5RieiJ5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5RieiJ5e, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5zeiANgd, 0, m, &sTabread_5zeiANgd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5RieiJ5e, 0, m, &cDelay_5RieiJ5e_sendMessage);
}

void Heavy_ChaffVerb::sTabread_5zeiANgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QqH8bE7t, HV_BINOP_SUBTRACT, 0, m, &cBinop_QqH8bE7t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_twLn03Sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcxj0JEZ, HV_BINOP_MAX, 0, m, &cBinop_tcxj0JEZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JoDXIAax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_twLn03Sz, HV_BINOP_MULTIPLY, 0, m, &cBinop_twLn03Sz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nPLjJZRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oggvrxA0_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5zeiANgd, 0, m, &sTabread_5zeiANgd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmKY0ab5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FLxKFNRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqH8bE7t, HV_BINOP_SUBTRACT, 1, m, &cBinop_QqH8bE7t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5RieiJ5e, 2, m, &cDelay_5RieiJ5e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lu0PcUik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FLxKFNRR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oggvrxA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RPhAdHnE, 0, m, &cDelay_RPhAdHnE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5RieiJ5e, 0, m, &cDelay_5RieiJ5e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zw651bbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcxj0JEZ, HV_BINOP_MAX, 1, m, &cBinop_tcxj0JEZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tcxj0JEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPLjJZRc, HV_BINOP_SUBTRACT, 1, m, &cBinop_nPLjJZRc_sendMessage);
}

void Heavy_ChaffVerb::cCast_BmKY0ab5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RPhAdHnE, 0, m, &cDelay_RPhAdHnE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WoGmfHpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RPhAdHnE, 2, m, &cDelay_RPhAdHnE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QqH8bE7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WoGmfHpP_sendMessage);
}

void Heavy_ChaffVerb::cCast_rc163Lnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ApEgP0Xq, 0, m, &cVar_ApEgP0Xq_sendMessage);
  cMsg_TY6U4juR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k4oIYlfJ, 0, m, &cTabhead_k4oIYlfJ_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_qF7ovFDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzO2tBfu, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZzO2tBfu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QPCqunoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XQ7PXnPX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XQ7PXnPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8HAv3pmo_sendMessage);
}

void Heavy_ChaffVerb::cVar_gOhnUmKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2RbfNpyM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_y3gYDxvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y3gYDxvQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYDFTj0o, 0, m, &cDelay_GYDFTj0o_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KxdxpacY, 0, m, &sTabread_KxdxpacY_sendMessage);
}

void Heavy_ChaffVerb::cDelay_GYDFTj0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GYDFTj0o, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KxdxpacY, 0, m, &sTabread_KxdxpacY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYDFTj0o, 0, m, &cDelay_GYDFTj0o_sendMessage);
}

void Heavy_ChaffVerb::sTabread_KxdxpacY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_35epTNIU, HV_BINOP_SUBTRACT, 0, m, &cBinop_35epTNIU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_aduDC76K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u2OihzGt, HV_BINOP_MAX, 0, m, &cBinop_u2OihzGt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8HAv3pmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aduDC76K, HV_BINOP_MULTIPLY, 0, m, &cBinop_aduDC76K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZzO2tBfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G9hdoh4S_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KxdxpacY, 0, m, &sTabread_KxdxpacY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cYMuXLmN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HpbupGee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_35epTNIU, HV_BINOP_SUBTRACT, 1, m, &cBinop_35epTNIU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYDFTj0o, 2, m, &cDelay_GYDFTj0o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2RbfNpyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HpbupGee_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G9hdoh4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y3gYDxvQ, 0, m, &cDelay_y3gYDxvQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GYDFTj0o, 0, m, &cDelay_GYDFTj0o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lZQpt6Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_u2OihzGt, HV_BINOP_MAX, 1, m, &cBinop_u2OihzGt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u2OihzGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzO2tBfu, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZzO2tBfu_sendMessage);
}

void Heavy_ChaffVerb::cCast_cYMuXLmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y3gYDxvQ, 0, m, &cDelay_y3gYDxvQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kJAkPPTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y3gYDxvQ, 2, m, &cDelay_y3gYDxvQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_35epTNIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kJAkPPTZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_JsSWh20H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gOhnUmKF, 0, m, &cVar_gOhnUmKF_sendMessage);
  cMsg_QPCqunoC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qF7ovFDX, 0, m, &cTabhead_qF7ovFDX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kTAXVVae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rd5H5f3I_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rd5H5f3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nVOkl3X9_sendMessage);
}

void Heavy_ChaffVerb::cDelay_63h73XxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_63h73XxR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hHuJWzNA, 0, m, &cDelay_hHuJWzNA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_63h73XxR, 0, m, &cDelay_63h73XxR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Be2e7QTJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hHuJWzNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hHuJWzNA, m);
  cMsg_vv7O620t_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_iHg2zev9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_k7yIUtp6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_nH1rlWzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AumyQcNJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_EKayMEtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRoo4Hah_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_63h73XxR, 2, m, &cDelay_63h73XxR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1ooBwX3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AumyQcNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_EKayMEtr, 0, m, &hTable_EKayMEtr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nVOkl3X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_nH1rlWzX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vv7O620t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_EKayMEtr, 0, m, &hTable_EKayMEtr_sendMessage);
}

void Heavy_ChaffVerb::cCast_c1ooBwX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_63h73XxR, 0, m, &cDelay_63h73XxR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yRoo4Hah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hHuJWzNA, 2, m, &cDelay_hHuJWzNA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k7yIUtp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Be2e7QTJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_8bwmD84w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JxFKTcGj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JxFKTcGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Sjxga2pX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iHWbdVcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iHWbdVcY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DvaiUoy4, 0, m, &cDelay_DvaiUoy4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iHWbdVcY, 0, m, &cDelay_iHWbdVcY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3i2N9rQ8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_DvaiUoy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DvaiUoy4, m);
  cMsg_xXBYzQF7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_EBi2ZeCY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_NHjWuEea_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_QKI0sWNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qEta91f_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_EdKgNVIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OGQO2xKm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iHWbdVcY, 2, m, &cDelay_iHWbdVcY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K1RXVXOo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2qEta91f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_EdKgNVIX, 0, m, &hTable_EdKgNVIX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Sjxga2pX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_QKI0sWNG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xXBYzQF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_EdKgNVIX, 0, m, &hTable_EdKgNVIX_sendMessage);
}

void Heavy_ChaffVerb::cCast_K1RXVXOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iHWbdVcY, 0, m, &cDelay_iHWbdVcY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OGQO2xKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DvaiUoy4, 2, m, &cDelay_DvaiUoy4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NHjWuEea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3i2N9rQ8, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_qrdRDvo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_137zSy7p_sendMessage);
}

void Heavy_ChaffVerb::cSystem_137zSy7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gkgmWr5D_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2F8zWUy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2F8zWUy1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eBVMARli, 0, m, &cDelay_eBVMARli_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2F8zWUy1, 0, m, &cDelay_2F8zWUy1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ndgyGCyS, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_eBVMARli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eBVMARli, m);
  cMsg_yaEDoK4Z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HuiCTeOx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Q8LJMvjG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Oem6U7hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nn21Zhdn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_tqKcplW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_343oiKme_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2F8zWUy1, 2, m, &cDelay_2F8zWUy1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UN7uEZz5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nn21Zhdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tqKcplW8, 0, m, &hTable_tqKcplW8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gkgmWr5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_Oem6U7hE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yaEDoK4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tqKcplW8, 0, m, &hTable_tqKcplW8_sendMessage);
}

void Heavy_ChaffVerb::cCast_UN7uEZz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2F8zWUy1, 0, m, &cDelay_2F8zWUy1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_343oiKme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_eBVMARli, 2, m, &cDelay_eBVMARli_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q8LJMvjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ndgyGCyS, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_U7gfNjm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S1LQqgUn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_S1LQqgUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YthDV6EY_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xGOCK1Wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xGOCK1Wy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZwEnOSj, 0, m, &cDelay_2ZwEnOSj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGOCK1Wy, 0, m, &cDelay_xGOCK1Wy_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r9yAMZTg, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_2ZwEnOSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2ZwEnOSj, m);
  cMsg_kP8rnfDD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_p1FnCjfr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LkNqgh4L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ph6LtCgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p85YztDn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_eyu9PmsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g8UcdYYw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGOCK1Wy, 2, m, &cDelay_xGOCK1Wy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MMiere2j_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p85YztDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_eyu9PmsV, 0, m, &hTable_eyu9PmsV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YthDV6EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_ph6LtCgG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kP8rnfDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_eyu9PmsV, 0, m, &hTable_eyu9PmsV_sendMessage);
}

void Heavy_ChaffVerb::cCast_MMiere2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGOCK1Wy, 0, m, &cDelay_xGOCK1Wy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_g8UcdYYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZwEnOSj, 2, m, &cDelay_2ZwEnOSj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LkNqgh4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r9yAMZTg, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_ZB5AFMFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_7tzfj00M, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_F9o998ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_AQ2mKBFw, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_5BLqaItw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2O2AVR80_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2O2AVR80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_ulw8tL6u_sendMessage);
}

void Heavy_ChaffVerb::cVar_c7TnuvkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sWzRYI0, HV_BINOP_MULTIPLY, 0, m, &cBinop_2sWzRYI0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tkBSdqt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AGGiVUtz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AGGiVUtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CcT4APwF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_2sWzRYI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Vm8qKQZW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t4wTJIJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2sWzRYI0, HV_BINOP_MULTIPLY, 1, m, &cBinop_2sWzRYI0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CcT4APwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_t4wTJIJo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vm8qKQZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qQyBTeQL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qQyBTeQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bgIuO2JX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wpYfVd94, m);
}

void Heavy_ChaffVerb::cBinop_bgIuO2JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0yuIjbUX, m);
}

void Heavy_ChaffVerb::cVar_LhTRrR5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_rBN2voW7_sendMessage);
}

void Heavy_ChaffVerb::cVar_GmG7Z0A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5BLqaItw_sendMessage);
}

void Heavy_ChaffVerb::cVar_CpIYPq7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_rfH4OddQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rDbqZAtp, 0, m, &cIf_rDbqZAtp_sendMessage);
}

void Heavy_ChaffVerb::cVar_atxWBLLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zoTrgGID_sendMessage);
}

void Heavy_ChaffVerb::cIf_rDbqZAtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uE2Ts6vh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FCrkW78h, 0, m, &cVar_FCrkW78h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rfH4OddQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDbqZAtp, 1, m, &cIf_rDbqZAtp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zoTrgGID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ltNKIPH3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ltNKIPH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oRASUuQ3, 0, m, &cVar_oRASUuQ3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HDKAsduh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FFbSV7wk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FFbSV7wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CTqtmFRQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_yv9eZCBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yv9eZCBX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GCnptN1u, 0, m, &cDelay_GCnptN1u_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yv9eZCBX, 0, m, &cDelay_yv9eZCBX_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_agVDldlT, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_GCnptN1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GCnptN1u, m);
  cMsg_MqIi4mwh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ekvQozLa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_J8J3FNWB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_qBrHPAM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1sBYLcrR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_txzS0m3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WsKFDzXp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yv9eZCBX, 2, m, &cDelay_yv9eZCBX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8NwN9hCe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1sBYLcrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_txzS0m3F, 0, m, &hTable_txzS0m3F_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CTqtmFRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_qBrHPAM8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MqIi4mwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_txzS0m3F, 0, m, &hTable_txzS0m3F_sendMessage);
}

void Heavy_ChaffVerb::cCast_8NwN9hCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yv9eZCBX, 0, m, &cDelay_yv9eZCBX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WsKFDzXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_GCnptN1u, 2, m, &cDelay_GCnptN1u_sendMessage);
}

void Heavy_ChaffVerb::cMsg_J8J3FNWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_agVDldlT, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vtr7MPsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aJF8A82M, HV_BINOP_SUBTRACT, 0, m, &cBinop_aJF8A82M_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NfVyOLLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i5telGUa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_i5telGUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bReImFcG_sendMessage);
}

void Heavy_ChaffVerb::cVar_sCYjb2Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b770Q4C6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CYjmI4Oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CYjmI4Oz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_91yk2Psw, 0, m, &cDelay_91yk2Psw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pf1cY1OZ, 0, m, &sTabread_pf1cY1OZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_91yk2Psw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_91yk2Psw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pf1cY1OZ, 0, m, &sTabread_pf1cY1OZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_91yk2Psw, 0, m, &cDelay_91yk2Psw_sendMessage);
}

void Heavy_ChaffVerb::sTabread_pf1cY1OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3ZN4CapC, HV_BINOP_SUBTRACT, 0, m, &cBinop_3ZN4CapC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_seQnfdqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pb2EKpY2, HV_BINOP_MAX, 0, m, &cBinop_Pb2EKpY2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bReImFcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_seQnfdqB, HV_BINOP_MULTIPLY, 0, m, &cBinop_seQnfdqB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aJF8A82M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_awE6qQaQ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pf1cY1OZ, 0, m, &sTabread_pf1cY1OZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3744cYS6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eAkhH8Ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZN4CapC, HV_BINOP_SUBTRACT, 1, m, &cBinop_3ZN4CapC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_91yk2Psw, 2, m, &cDelay_91yk2Psw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b770Q4C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eAkhH8Ry_sendMessage);
}

void Heavy_ChaffVerb::cMsg_awE6qQaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CYjmI4Oz, 0, m, &cDelay_CYjmI4Oz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_91yk2Psw, 0, m, &cDelay_91yk2Psw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rGvRRSrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pb2EKpY2, HV_BINOP_MAX, 1, m, &cBinop_Pb2EKpY2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Pb2EKpY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aJF8A82M, HV_BINOP_SUBTRACT, 1, m, &cBinop_aJF8A82M_sendMessage);
}

void Heavy_ChaffVerb::cCast_3744cYS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CYjmI4Oz, 0, m, &cDelay_CYjmI4Oz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OkMxRfdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CYjmI4Oz, 2, m, &cDelay_CYjmI4Oz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3ZN4CapC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OkMxRfdk_sendMessage);
}

void Heavy_ChaffVerb::cCast_AL14u1rT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sCYjb2Hl, 0, m, &cVar_sCYjb2Hl_sendMessage);
  cMsg_NfVyOLLT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vtr7MPsj, 0, m, &cTabhead_vtr7MPsj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gw9nTJi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jiYNmSrh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jiYNmSrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9ZYRnMHM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Ek5hffi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ek5hffi9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_70elUr3s, 0, m, &cDelay_70elUr3s_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ek5hffi9, 0, m, &cDelay_Ek5hffi9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yVHo2jC2, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_70elUr3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_70elUr3s, m);
  cMsg_NhkvfktU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ypxSVdoM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qLIXzP6d_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_FLWaBFz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wlPmPYyK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_67dsIc73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SHH5jzbE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ek5hffi9, 2, m, &cDelay_Ek5hffi9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a4Pq4HaD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wlPmPYyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_67dsIc73, 0, m, &hTable_67dsIc73_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9ZYRnMHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_FLWaBFz7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NhkvfktU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_67dsIc73, 0, m, &hTable_67dsIc73_sendMessage);
}

void Heavy_ChaffVerb::cCast_a4Pq4HaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ek5hffi9, 0, m, &cDelay_Ek5hffi9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SHH5jzbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_70elUr3s, 2, m, &cDelay_70elUr3s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qLIXzP6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yVHo2jC2, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Cbu2a9jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCecfaUP, HV_BINOP_SUBTRACT, 0, m, &cBinop_fCecfaUP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RTg39Stq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ljdfwD3J_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ljdfwD3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bALyCEyw_sendMessage);
}

void Heavy_ChaffVerb::cVar_sGoJGP5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7PVbieAI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_BuGzP4a9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BuGzP4a9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJpQ0al, 0, m, &cDelay_zyJpQ0al_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dQGshT1h, 0, m, &sTabread_dQGshT1h_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zyJpQ0al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zyJpQ0al, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dQGshT1h, 0, m, &sTabread_dQGshT1h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJpQ0al, 0, m, &cDelay_zyJpQ0al_sendMessage);
}

void Heavy_ChaffVerb::sTabread_dQGshT1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Yn3XTgvL, HV_BINOP_SUBTRACT, 0, m, &cBinop_Yn3XTgvL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_9CizaDQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cN5IfL6m, HV_BINOP_MAX, 0, m, &cBinop_cN5IfL6m_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bALyCEyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9CizaDQB, HV_BINOP_MULTIPLY, 0, m, &cBinop_9CizaDQB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fCecfaUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qkLBg2yB_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dQGshT1h, 0, m, &sTabread_dQGshT1h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ljnBrrMI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_izsKatBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yn3XTgvL, HV_BINOP_SUBTRACT, 1, m, &cBinop_Yn3XTgvL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJpQ0al, 2, m, &cDelay_zyJpQ0al_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7PVbieAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_izsKatBa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qkLBg2yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BuGzP4a9, 0, m, &cDelay_BuGzP4a9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJpQ0al, 0, m, &cDelay_zyJpQ0al_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IdNjwYSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_cN5IfL6m, HV_BINOP_MAX, 1, m, &cBinop_cN5IfL6m_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cN5IfL6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCecfaUP, HV_BINOP_SUBTRACT, 1, m, &cBinop_fCecfaUP_sendMessage);
}

void Heavy_ChaffVerb::cCast_ljnBrrMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BuGzP4a9, 0, m, &cDelay_BuGzP4a9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3ITuL5M9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BuGzP4a9, 2, m, &cDelay_BuGzP4a9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Yn3XTgvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3ITuL5M9_sendMessage);
}

void Heavy_ChaffVerb::cCast_qdEiJlSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sGoJGP5L, 0, m, &cVar_sGoJGP5L_sendMessage);
  cMsg_RTg39Stq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Cbu2a9jP, 0, m, &cTabhead_Cbu2a9jP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Nc5wDMUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0NhIRryw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0NhIRryw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_X2Jaiumj_sendMessage);
}

void Heavy_ChaffVerb::cDelay_toAXgDXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_toAXgDXl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxzSf9pe, 0, m, &cDelay_qxzSf9pe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_toAXgDXl, 0, m, &cDelay_toAXgDXl_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8vhIuJU1, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_qxzSf9pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qxzSf9pe, m);
  cMsg_A7zLq0vn_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_P0BImbC2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BusX5hzK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_djWOTh2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qjI5fIs7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_sqj6Gv21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UJI5oJMd_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_toAXgDXl, 2, m, &cDelay_toAXgDXl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c8Q4wM3d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qjI5fIs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sqj6Gv21, 0, m, &hTable_sqj6Gv21_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X2Jaiumj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_djWOTh2R_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A7zLq0vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sqj6Gv21, 0, m, &hTable_sqj6Gv21_sendMessage);
}

void Heavy_ChaffVerb::cCast_c8Q4wM3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_toAXgDXl, 0, m, &cDelay_toAXgDXl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UJI5oJMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qxzSf9pe, 2, m, &cDelay_qxzSf9pe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BusX5hzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8vhIuJU1, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ShQPLGxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSEWGBg3, HV_BINOP_SUBTRACT, 0, m, &cBinop_QSEWGBg3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uVLSVJSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4M92FgSj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4M92FgSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_N7ygxQpO_sendMessage);
}

void Heavy_ChaffVerb::cVar_arFAj48c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yhjd3UTv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ZLCkeDzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZLCkeDzo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ5kWxsv, 0, m, &cDelay_IQ5kWxsv_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CGNBqTxo, 0, m, &sTabread_CGNBqTxo_sendMessage);
}

void Heavy_ChaffVerb::cDelay_IQ5kWxsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IQ5kWxsv, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CGNBqTxo, 0, m, &sTabread_CGNBqTxo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ5kWxsv, 0, m, &cDelay_IQ5kWxsv_sendMessage);
}

void Heavy_ChaffVerb::sTabread_CGNBqTxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_qmcIv0ir, HV_BINOP_SUBTRACT, 0, m, &cBinop_qmcIv0ir_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uOqqeUuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCfwx3Ej, HV_BINOP_MAX, 0, m, &cBinop_kCfwx3Ej_sendMessage);
}

void Heavy_ChaffVerb::cBinop_N7ygxQpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uOqqeUuR, HV_BINOP_MULTIPLY, 0, m, &cBinop_uOqqeUuR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QSEWGBg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TDJghSyh_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CGNBqTxo, 0, m, &sTabread_CGNBqTxo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FsIEHIFn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PtUv2XZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qmcIv0ir, HV_BINOP_SUBTRACT, 1, m, &cBinop_qmcIv0ir_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ5kWxsv, 2, m, &cDelay_IQ5kWxsv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Yhjd3UTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PtUv2XZh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TDJghSyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZLCkeDzo, 0, m, &cDelay_ZLCkeDzo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ5kWxsv, 0, m, &cDelay_IQ5kWxsv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gS2mI6Tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCfwx3Ej, HV_BINOP_MAX, 1, m, &cBinop_kCfwx3Ej_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kCfwx3Ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSEWGBg3, HV_BINOP_SUBTRACT, 1, m, &cBinop_QSEWGBg3_sendMessage);
}

void Heavy_ChaffVerb::cCast_FsIEHIFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZLCkeDzo, 0, m, &cDelay_ZLCkeDzo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aNIlsdWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZLCkeDzo, 2, m, &cDelay_ZLCkeDzo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qmcIv0ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aNIlsdWm_sendMessage);
}

void Heavy_ChaffVerb::cCast_DZ8dJNxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_arFAj48c, 0, m, &cVar_arFAj48c_sendMessage);
  cMsg_uVLSVJSt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ShQPLGxc, 0, m, &cTabhead_ShQPLGxc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bc0cJU9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AaqRhzIf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AaqRhzIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5wf7oZnm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_p5V7uuEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p5V7uuEd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNFFrEaG, 0, m, &cDelay_oNFFrEaG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5V7uuEd, 0, m, &cDelay_p5V7uuEd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cT1TOIgt, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_oNFFrEaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oNFFrEaG, m);
  cMsg_B17Oyc0k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Nmvn94g7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1l58Pcfl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_RdGJyXmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JEBfkPFz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_OLBoYshR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EVYZ8ZjP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5V7uuEd, 2, m, &cDelay_p5V7uuEd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OJPKJhhL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JEBfkPFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OLBoYshR, 0, m, &hTable_OLBoYshR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5wf7oZnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_RdGJyXmD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B17Oyc0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OLBoYshR, 0, m, &hTable_OLBoYshR_sendMessage);
}

void Heavy_ChaffVerb::cCast_OJPKJhhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5V7uuEd, 0, m, &cDelay_p5V7uuEd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EVYZ8ZjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNFFrEaG, 2, m, &cDelay_oNFFrEaG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1l58Pcfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cT1TOIgt, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_XMjmXHm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UurXqLbV, HV_BINOP_SUBTRACT, 0, m, &cBinop_UurXqLbV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gLo0u6O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0ukmoNvg_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0ukmoNvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k3FzVlSR_sendMessage);
}

void Heavy_ChaffVerb::cVar_zNcW3vl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XOITFC0I_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_SrxYqqcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SrxYqqcB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tPtkYzO2, 0, m, &cDelay_tPtkYzO2_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ar597HbC, 0, m, &sTabread_Ar597HbC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_tPtkYzO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tPtkYzO2, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ar597HbC, 0, m, &sTabread_Ar597HbC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tPtkYzO2, 0, m, &cDelay_tPtkYzO2_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Ar597HbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2gviRA9G, HV_BINOP_SUBTRACT, 0, m, &cBinop_2gviRA9G_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_jYreV6Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8Hxqdar, HV_BINOP_MAX, 0, m, &cBinop_y8Hxqdar_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k3FzVlSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jYreV6Nw, HV_BINOP_MULTIPLY, 0, m, &cBinop_jYreV6Nw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UurXqLbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uAjWjapI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ar597HbC, 0, m, &sTabread_Ar597HbC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wV3t59F2_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WzGYIXTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2gviRA9G, HV_BINOP_SUBTRACT, 1, m, &cBinop_2gviRA9G_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tPtkYzO2, 2, m, &cDelay_tPtkYzO2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XOITFC0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WzGYIXTO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uAjWjapI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SrxYqqcB, 0, m, &cDelay_SrxYqqcB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tPtkYzO2, 0, m, &cDelay_tPtkYzO2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nHGo37Wf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8Hxqdar, HV_BINOP_MAX, 1, m, &cBinop_y8Hxqdar_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y8Hxqdar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UurXqLbV, HV_BINOP_SUBTRACT, 1, m, &cBinop_UurXqLbV_sendMessage);
}

void Heavy_ChaffVerb::cCast_wV3t59F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SrxYqqcB, 0, m, &cDelay_SrxYqqcB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IhkUBnFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SrxYqqcB, 2, m, &cDelay_SrxYqqcB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2gviRA9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IhkUBnFN_sendMessage);
}

void Heavy_ChaffVerb::cCast_p9OIID6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zNcW3vl4, 0, m, &cVar_zNcW3vl4_sendMessage);
  cMsg_gLo0u6O8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XMjmXHm8, 0, m, &cTabhead_XMjmXHm8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ofgynSIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q0B4f79H_sendMessage);
}

void Heavy_ChaffVerb::cSystem_q0B4f79H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WKdxGRUI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_B90KveZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B90KveZJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lVJ9tmMx, 0, m, &cDelay_lVJ9tmMx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B90KveZJ, 0, m, &cDelay_B90KveZJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Lua8jujC, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_lVJ9tmMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lVJ9tmMx, m);
  cMsg_G6q0uASZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_DU6aoz8K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Rq4JiZxv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_IUngunOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3S7IXUvM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LGD1S3a7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qtNgyXwc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B90KveZJ, 2, m, &cDelay_B90KveZJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OmVy5m31_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3S7IXUvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LGD1S3a7, 0, m, &hTable_LGD1S3a7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WKdxGRUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_IUngunOs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G6q0uASZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LGD1S3a7, 0, m, &hTable_LGD1S3a7_sendMessage);
}

void Heavy_ChaffVerb::cCast_OmVy5m31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B90KveZJ, 0, m, &cDelay_B90KveZJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qtNgyXwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_lVJ9tmMx, 2, m, &cDelay_lVJ9tmMx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Rq4JiZxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Lua8jujC, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_8Q5xh1TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OTgPABbj, HV_BINOP_SUBTRACT, 0, m, &cBinop_OTgPABbj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mtscEtg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bdyhR0Df_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bdyhR0Df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vMr4Jxwf_sendMessage);
}

void Heavy_ChaffVerb::cVar_VwCYrC2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TUQiUZqu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_pBTWEHDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pBTWEHDq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSjs2KJg, 0, m, &cDelay_BSjs2KJg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PlP7xxbO, 0, m, &sTabread_PlP7xxbO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_BSjs2KJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BSjs2KJg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PlP7xxbO, 0, m, &sTabread_PlP7xxbO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSjs2KJg, 0, m, &cDelay_BSjs2KJg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_PlP7xxbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oQvCb5SR, HV_BINOP_SUBTRACT, 0, m, &cBinop_oQvCb5SR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_oVlkwZw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOUFajqj, HV_BINOP_MAX, 0, m, &cBinop_NOUFajqj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vMr4Jxwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oVlkwZw3, HV_BINOP_MULTIPLY, 0, m, &cBinop_oVlkwZw3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OTgPABbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TDGjgmkK_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PlP7xxbO, 0, m, &sTabread_PlP7xxbO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LJqbV0if_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yUrPyGYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oQvCb5SR, HV_BINOP_SUBTRACT, 1, m, &cBinop_oQvCb5SR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSjs2KJg, 2, m, &cDelay_BSjs2KJg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TUQiUZqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yUrPyGYI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TDGjgmkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pBTWEHDq, 0, m, &cDelay_pBTWEHDq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSjs2KJg, 0, m, &cDelay_BSjs2KJg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bVEN6Pwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOUFajqj, HV_BINOP_MAX, 1, m, &cBinop_NOUFajqj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NOUFajqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OTgPABbj, HV_BINOP_SUBTRACT, 1, m, &cBinop_OTgPABbj_sendMessage);
}

void Heavy_ChaffVerb::cCast_LJqbV0if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pBTWEHDq, 0, m, &cDelay_pBTWEHDq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SGeWmZAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pBTWEHDq, 2, m, &cDelay_pBTWEHDq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oQvCb5SR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SGeWmZAS_sendMessage);
}

void Heavy_ChaffVerb::cCast_vCwd662Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VwCYrC2v, 0, m, &cVar_VwCYrC2v_sendMessage);
  cMsg_mtscEtg5_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8Q5xh1TS, 0, m, &cTabhead_8Q5xh1TS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1w5qHdo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_03vqUSHl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_03vqUSHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gdMZG3dV_sendMessage);
}

void Heavy_ChaffVerb::cDelay_YFwW1sjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YFwW1sjR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_V6P1Nw4b, 0, m, &cDelay_V6P1Nw4b_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YFwW1sjR, 0, m, &cDelay_YFwW1sjR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6BE9JuDb, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_V6P1Nw4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V6P1Nw4b, m);
  cMsg_gSb8NUba_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_TIYvSgls_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yzOPMrjE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_rh1J81OQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QLoY1Pt3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_P5M6zS8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MuXLmmJB_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YFwW1sjR, 2, m, &cDelay_YFwW1sjR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OLjBrGyX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QLoY1Pt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_P5M6zS8g, 0, m, &hTable_P5M6zS8g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gdMZG3dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_rh1J81OQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gSb8NUba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_P5M6zS8g, 0, m, &hTable_P5M6zS8g_sendMessage);
}

void Heavy_ChaffVerb::cCast_OLjBrGyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YFwW1sjR, 0, m, &cDelay_YFwW1sjR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MuXLmmJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_V6P1Nw4b, 2, m, &cDelay_V6P1Nw4b_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yzOPMrjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6BE9JuDb, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_RcjBGe2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kifoick, HV_BINOP_SUBTRACT, 0, m, &cBinop_6kifoick_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cW4rDmAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4fkXku1X_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4fkXku1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qkqd49ok_sendMessage);
}

void Heavy_ChaffVerb::cVar_Ipge0nuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cZw2VJI0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_XxX8RSAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XxX8RSAt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_selS0FLf, 0, m, &cDelay_selS0FLf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ac5G6h9O, 0, m, &sTabread_ac5G6h9O_sendMessage);
}

void Heavy_ChaffVerb::cDelay_selS0FLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_selS0FLf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ac5G6h9O, 0, m, &sTabread_ac5G6h9O_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_selS0FLf, 0, m, &cDelay_selS0FLf_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ac5G6h9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JUrswIRx, HV_BINOP_SUBTRACT, 0, m, &cBinop_JUrswIRx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_E4xhRiJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WVq2n2OX, HV_BINOP_MAX, 0, m, &cBinop_WVq2n2OX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qkqd49ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E4xhRiJ1, HV_BINOP_MULTIPLY, 0, m, &cBinop_E4xhRiJ1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6kifoick_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dQdKkoiQ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ac5G6h9O, 0, m, &sTabread_ac5G6h9O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KfEWm9h9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_92XXtsen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JUrswIRx, HV_BINOP_SUBTRACT, 1, m, &cBinop_JUrswIRx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_selS0FLf, 2, m, &cDelay_selS0FLf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cZw2VJI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_92XXtsen_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dQdKkoiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XxX8RSAt, 0, m, &cDelay_XxX8RSAt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_selS0FLf, 0, m, &cDelay_selS0FLf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bPChFr66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WVq2n2OX, HV_BINOP_MAX, 1, m, &cBinop_WVq2n2OX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WVq2n2OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6kifoick, HV_BINOP_SUBTRACT, 1, m, &cBinop_6kifoick_sendMessage);
}

void Heavy_ChaffVerb::cCast_KfEWm9h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XxX8RSAt, 0, m, &cDelay_XxX8RSAt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_04BmFBi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XxX8RSAt, 2, m, &cDelay_XxX8RSAt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JUrswIRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_04BmFBi7_sendMessage);
}

void Heavy_ChaffVerb::cCast_qQNWlxo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ipge0nuF, 0, m, &cVar_Ipge0nuF_sendMessage);
  cMsg_cW4rDmAQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RcjBGe2N, 0, m, &cTabhead_RcjBGe2N_sendMessage);
}

void Heavy_ChaffVerb::cVar_FCrkW78h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c7TnuvkD, 0, m, &cVar_c7TnuvkD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JOc4gUNL, 0, m, &cVar_JOc4gUNL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7AzBkjGy, 0, m, &cVar_7AzBkjGy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hsop4NoO, 0, m, &cVar_Hsop4NoO_sendMessage);
}

void Heavy_ChaffVerb::cVar_oRASUuQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_MHBxAdFC_sendMessage);
}

void Heavy_ChaffVerb::cPack_9Ilmfz90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_CH5mHjGq, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_JOc4gUNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qan38BFa, HV_BINOP_MULTIPLY, 0, m, &cBinop_qan38BFa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8D3SHrtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7jlOOc03_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7jlOOc03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IpSCqJ5m_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_qan38BFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TZlbOL0W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_juuRPnwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qan38BFa, HV_BINOP_MULTIPLY, 1, m, &cBinop_qan38BFa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IpSCqJ5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_juuRPnwb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TZlbOL0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SwCBuAEI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SwCBuAEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Cq4zGKj3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GgRgiQ3q, m);
}

void Heavy_ChaffVerb::cBinop_Cq4zGKj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_324nPTEl, m);
}

void Heavy_ChaffVerb::cVar_7AzBkjGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qxq8lasf, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qxq8lasf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fDu8Ryql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GOXGzsdd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GOXGzsdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S6BYtBkC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_Qxq8lasf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_G0kpSjEf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9zcZ3mDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qxq8lasf, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qxq8lasf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S6BYtBkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9zcZ3mDn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G0kpSjEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BnAPBRL9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BnAPBRL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vfKGVquy_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_o140dlFp, m);
}

void Heavy_ChaffVerb::cBinop_vfKGVquy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_McgoWCYH, m);
}

void Heavy_ChaffVerb::cVar_Hsop4NoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCGsnc1U, HV_BINOP_MULTIPLY, 0, m, &cBinop_CCGsnc1U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kna4FNWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tuHkyjPA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tuHkyjPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zHOfa4wd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_CCGsnc1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_imaFQ8Oo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h30nkqYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCGsnc1U, HV_BINOP_MULTIPLY, 1, m, &cBinop_CCGsnc1U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zHOfa4wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_h30nkqYo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_imaFQ8Oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MJgud4Sm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MJgud4Sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VtCKTnWc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FdTt7rFV, m);
}

void Heavy_ChaffVerb::cBinop_VtCKTnWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RPMr8mCh, m);
}

void Heavy_ChaffVerb::cBinop_ulw8tL6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_F9o998ik, 0, m, &cPack_F9o998ik_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uE2Ts6vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FCrkW78h, 0, m, &cVar_FCrkW78h_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MHBxAdFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_9Ilmfz90, 0, m, &cPack_9Ilmfz90_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rBN2voW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ZB5AFMFR, 0, m, &cPack_ZB5AFMFR_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_XK62Ipev_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_zzsmPbGD_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_zzsmPbGD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wndDZfeE_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_JDiFOI54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JDiFOI54, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDiFOI54, 0, m, &cDelay_JDiFOI54_sendMessage);
  cSwitchcase_y36gZAy4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_wndDZfeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zzsmPbGD_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDiFOI54, 0, m, &cDelay_JDiFOI54_sendMessage);
  cSwitchcase_y36gZAy4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_2tidil4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wHvDeleR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wHvDeleR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_v0SIVsUi_sendMessage);
}

void Heavy_ChaffVerb::cVar_lKopx8YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkUbKgAB, HV_BINOP_MULTIPLY, 0, m, &cBinop_EkUbKgAB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zzsmPbGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDiFOI54, 0, m, &cDelay_JDiFOI54_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xfwsKrOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDiFOI54, 2, m, &cDelay_JDiFOI54_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v0SIVsUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkUbKgAB, HV_BINOP_MULTIPLY, 1, m, &cBinop_EkUbKgAB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EkUbKgAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_xfwsKrOH_sendMessage);
}

void Heavy_ChaffVerb::cVar_YMTWA6Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_krW82gcu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_Q93rku7x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_x8h1MNof_sendMessage);
}

void Heavy_ChaffVerb::cVar_W8PI1Ks0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BiW0UOUu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ra39Mn9U, 0, m, &cIf_ra39Mn9U_sendMessage);
}

void Heavy_ChaffVerb::cUnop_mVyZ3KP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XP5f9QlP, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_XP5f9QlP_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jnjAcD9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XP5f9QlP, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_XP5f9QlP_sendMessage);
}

void Heavy_ChaffVerb::cIf_ra39Mn9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_jnjAcD9U_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_mVyZ3KP3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BiW0UOUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ra39Mn9U, 1, m, &cIf_ra39Mn9U_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kyXu3HCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JhB1ScGR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JhB1ScGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h9153C9K_sendMessage);
}

void Heavy_ChaffVerb::cDelay_g84JUwSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g84JUwSd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8dknvqYF, 0, m, &cDelay_8dknvqYF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g84JUwSd, 0, m, &cDelay_g84JUwSd_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LsxhWH34, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_8dknvqYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8dknvqYF, m);
  cMsg_fuDnuwSG_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_yb4OcyDe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wX7VqTmq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_JolMM7nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yNFPWypD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5zsnKKWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6levzRH9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g84JUwSd, 2, m, &cDelay_g84JUwSd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBp9U4cJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yNFPWypD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5zsnKKWw, 0, m, &hTable_5zsnKKWw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h9153C9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_JolMM7nZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fuDnuwSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5zsnKKWw, 0, m, &hTable_5zsnKKWw_sendMessage);
}

void Heavy_ChaffVerb::cCast_TBp9U4cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g84JUwSd, 0, m, &cDelay_g84JUwSd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6levzRH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8dknvqYF, 2, m, &cDelay_8dknvqYF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wX7VqTmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LsxhWH34, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_a4iWH7aM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLDC9Jbk, HV_BINOP_SUBTRACT, 0, m, &cBinop_JLDC9Jbk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Gl70eWFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZbGQkUVK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZbGQkUVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hDyyBkyC_sendMessage);
}

void Heavy_ChaffVerb::cVar_2qlQJWGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fTgcucfF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_26kMPbsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_26kMPbsI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r8t5lnge, 0, m, &cDelay_r8t5lnge_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ToDGYBaJ, 0, m, &sTabread_ToDGYBaJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_r8t5lnge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r8t5lnge, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ToDGYBaJ, 0, m, &sTabread_ToDGYBaJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r8t5lnge, 0, m, &cDelay_r8t5lnge_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ToDGYBaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Cg8q8E2K, HV_BINOP_SUBTRACT, 0, m, &cBinop_Cg8q8E2K_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8lewcrIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R4yCBlc4, HV_BINOP_MAX, 0, m, &cBinop_R4yCBlc4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hDyyBkyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lewcrIg, HV_BINOP_MULTIPLY, 0, m, &cBinop_8lewcrIg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JLDC9Jbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iPWYNRtO_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ToDGYBaJ, 0, m, &sTabread_ToDGYBaJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_to6UPzCJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xVob4JU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cg8q8E2K, HV_BINOP_SUBTRACT, 1, m, &cBinop_Cg8q8E2K_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r8t5lnge, 2, m, &cDelay_r8t5lnge_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fTgcucfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xVob4JU0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iPWYNRtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_26kMPbsI, 0, m, &cDelay_26kMPbsI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r8t5lnge, 0, m, &cDelay_r8t5lnge_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DCHn5tRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_R4yCBlc4, HV_BINOP_MAX, 1, m, &cBinop_R4yCBlc4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R4yCBlc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLDC9Jbk, HV_BINOP_SUBTRACT, 1, m, &cBinop_JLDC9Jbk_sendMessage);
}

void Heavy_ChaffVerb::cCast_to6UPzCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_26kMPbsI, 0, m, &cDelay_26kMPbsI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CdUVFIGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_26kMPbsI, 2, m, &cDelay_26kMPbsI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Cg8q8E2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CdUVFIGA_sendMessage);
}

void Heavy_ChaffVerb::cCast_dhadvgLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2qlQJWGo, 0, m, &cVar_2qlQJWGo_sendMessage);
  cMsg_Gl70eWFW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_a4iWH7aM, 0, m, &cTabhead_a4iWH7aM_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_4sJ5IvBy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7jOTPdgL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_7jOTPdgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c0ISHmmL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_ynS8j7NF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EDVUvA64, HV_BINOP_ADD, 0, m, &cBinop_EDVUvA64_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_u2FDj0hG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DqJmbyG3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_DqJmbyG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rnPRTrev_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_PSQHFZnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckoLO05k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ER1tpx7_sendMessage);
}

void Heavy_ChaffVerb::cVar_dx8pN6IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XMtppSrt, 0, m, &cVar_XMtppSrt_sendMessage);
}

void Heavy_ChaffVerb::cVar_XMtppSrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s7kB6mPh, HV_BINOP_ADD, 0, m, &cBinop_s7kB6mPh_sendMessage);
}

void Heavy_ChaffVerb::cVar_AewI9EU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHtV8W8t, HV_BINOP_ADD, 0, m, &cBinop_bHtV8W8t_sendMessage);
}

void Heavy_ChaffVerb::cVar_y0m9Hj0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uMjWJIUp_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WdxqdmeS, 0, m, &cIf_WdxqdmeS_sendMessage);
}

void Heavy_ChaffVerb::cUnop_ehlo9gKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHtV8W8t, HV_BINOP_ADD, 1, m, &cBinop_bHtV8W8t_sendMessage);
}

void Heavy_ChaffVerb::cUnop_TdjB8y2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHtV8W8t, HV_BINOP_ADD, 1, m, &cBinop_bHtV8W8t_sendMessage);
}

void Heavy_ChaffVerb::cIf_WdxqdmeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_TdjB8y2c_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_ehlo9gKF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uMjWJIUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WdxqdmeS, 1, m, &cIf_WdxqdmeS_sendMessage);
}

void Heavy_ChaffVerb::cVar_iumINCfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xC19vK2X_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ro31Ito7, 0, m, &cIf_ro31Ito7_sendMessage);
}

void Heavy_ChaffVerb::cUnop_t1ZoaNIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rM1iAzOU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_zCFhCFmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rM1iAzOU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_ro31Ito7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_zCFhCFmc_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_t1ZoaNIj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xC19vK2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ro31Ito7, 1, m, &cIf_ro31Ito7_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_rM1iAzOU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vJcHjdy6, 0, m, &cSlice_vJcHjdy6_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IMcvW2dx, 0, m, &cSlice_IMcvW2dx_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5KeX9ckr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bKuMbYZY_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_vJcHjdy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_JBFW89HD, 0, m, &cVar_JBFW89HD_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JBFW89HD, 0, m, &cVar_JBFW89HD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_IMcvW2dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_cgDwXHic, HV_BINOP_NEQ, 1, m, &cBinop_cgDwXHic_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JBFW89HD, 1, m, &cVar_JBFW89HD_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_cgDwXHic, HV_BINOP_NEQ, 1, m, &cBinop_cgDwXHic_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JBFW89HD, 1, m, &cVar_JBFW89HD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_JBFW89HD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iJsA2L5e_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YoX5Bi6R_sendMessage);
}

void Heavy_ChaffVerb::cIf_9YqV6HSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eDTE1G4m_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fYI8s6VM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_eDTE1G4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cgDwXHic, HV_BINOP_NEQ, 1, m, &cBinop_cgDwXHic_sendMessage);
}

void Heavy_ChaffVerb::cCast_fYI8s6VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JBFW89HD, 0, m, &cVar_JBFW89HD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cgDwXHic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9YqV6HSo, 1, m, &cIf_9YqV6HSo_sendMessage);
}

void Heavy_ChaffVerb::cCast_5KeX9ckr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cgDwXHic, HV_BINOP_NEQ, 0, m, &cBinop_cgDwXHic_sendMessage);
}

void Heavy_ChaffVerb::cCast_bKuMbYZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9YqV6HSo, 0, m, &cIf_9YqV6HSo_sendMessage);
}

void Heavy_ChaffVerb::cIf_dhHXNhqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_sCyh0rC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dhHXNhqU, 0, m, &cIf_dhHXNhqU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_6DCJQn3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dhHXNhqU, 0, m, &cIf_dhHXNhqU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_sRRX6sHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dhHXNhqU, 0, m, &cIf_dhHXNhqU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_sCmttUiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_PSQHFZnF, 0, m, &cVar_PSQHFZnF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_xbmerv5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AewI9EU3, 0, m, &cVar_AewI9EU3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sg2vsWzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sCyh0rC1, 1, m, &cIf_sCyh0rC1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_M6Vdx01L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sRRX6sHh, 1, m, &cIf_sRRX6sHh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2w7B95I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sCyh0rC1, 1, m, &cIf_sCyh0rC1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_6DCJQn3p, 1, m, &cIf_6DCJQn3p_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sRRX6sHh, 1, m, &cIf_sRRX6sHh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tPMDQGzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ynS8j7NF, 0, m, &cVar_ynS8j7NF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iYRQ5bNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_tPMDQGzH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rnPRTrev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PSQHFZnF, 0, m, &cVar_PSQHFZnF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XP5f9QlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_legh2Dm1, HV_BINOP_MULTIPLY, 0, m, &cBinop_legh2Dm1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x8h1MNof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XP5f9QlP, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_XP5f9QlP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A8DK0CS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6DCJQn3p, 1, m, &cIf_6DCJQn3p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bHtV8W8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HDazuGjz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lr4frcNO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CDLtUnpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jxc8nh7e, 0, m, &cVar_jxc8nh7e_sendMessage);
}

void Heavy_ChaffVerb::cCast_HDazuGjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDLtUnpj, HV_BINOP_ADD, 1, m, &cBinop_CDLtUnpj_sendMessage);
}

void Heavy_ChaffVerb::cCast_Lr4frcNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
}

void Heavy_ChaffVerb::cCast_YoX5Bi6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IfC2YEte_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_iJsA2L5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2w7B95I6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_iFy8oZvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GmG7Z0A3, 0, m, &cVar_GmG7Z0A3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_legh2Dm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6DCJQn3p, 0, m, &cIf_6DCJQn3p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qUZ3J7cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sRRX6sHh, 0, m, &cIf_sRRX6sHh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iIWEqnJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Y1bQi8LR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_qUZ3J7cI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_krW82gcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_6Pla3vfm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6Pla3vfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_iIWEqnJB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q93rku7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YMTWA6Vu, 1, m, &cVar_YMTWA6Vu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NpRO8Bgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gcjymb3k, 0, m, &cVar_Gcjymb3k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xBjcimm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lKopx8YH, 0, m, &cVar_lKopx8YH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c0ISHmmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EDVUvA64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XSihFHz7, HV_BINOP_MULTIPLY, 0, m, &cBinop_XSihFHz7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XSihFHz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCmttUiq, 0, m, &cIf_sCmttUiq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3bpk0Wdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDLtUnpj, HV_BINOP_ADD, 0, m, &cBinop_CDLtUnpj_sendMessage);
}

void Heavy_ChaffVerb::cCast_ckoLO05k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3bpk0Wdl, HV_BINOP_ADD, 1, m, &cBinop_3bpk0Wdl_sendMessage);
}

void Heavy_ChaffVerb::cCast_1ER1tpx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
}

void Heavy_ChaffVerb::cCast_Y2qdH11F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4sJ5IvBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kdtccGXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dhHXNhqU, 1, m, &cIf_dhHXNhqU_sendMessage);
}

void Heavy_ChaffVerb::cCast_deo0CsBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ynS8j7NF, 0, m, &cVar_ynS8j7NF_sendMessage);
}

void Heavy_ChaffVerb::cCast_b8XUaSwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XSihFHz7, HV_BINOP_MULTIPLY, 1, m, &cBinop_XSihFHz7_sendMessage);
}

void Heavy_ChaffVerb::cCast_KsKRP83f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u2FDj0hG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_jk5cOU1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCmttUiq, 1, m, &cIf_sCmttUiq_sendMessage);
}

void Heavy_ChaffVerb::cCast_Eqy0F4yQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ynS8j7NF, 0, m, &cVar_ynS8j7NF_sendMessage);
}

void Heavy_ChaffVerb::cCast_njw3luQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EDVUvA64, HV_BINOP_ADD, 1, m, &cBinop_EDVUvA64_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lfZXyzi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3bpk0Wdl, HV_BINOP_ADD, 0, m, &cBinop_3bpk0Wdl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s7kB6mPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lfZXyzi2, HV_BINOP_MULTIPLY, 0, m, &cBinop_lfZXyzi2_sendMessage);
}

void Heavy_ChaffVerb::cCast_sxXjg6k2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
}

void Heavy_ChaffVerb::cCast_8S6LTRx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lfZXyzi2, HV_BINOP_MULTIPLY, 1, m, &cBinop_lfZXyzi2_sendMessage);
}

void Heavy_ChaffVerb::cCast_QV6ahpu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s7kB6mPh, HV_BINOP_ADD, 1, m, &cBinop_s7kB6mPh_sendMessage);
}

void Heavy_ChaffVerb::cCast_K2Q4k9ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dx8pN6IR, 0, m, &cVar_dx8pN6IR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aj55TDHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iJsA2L5e_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YoX5Bi6R_sendMessage);
}

void Heavy_ChaffVerb::cReceive_bEBGX5CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HDKAsduh_sendMessage(_c, 0, m);
  cMsg_gw9nTJi2_sendMessage(_c, 0, m);
  cMsg_Nc5wDMUp_sendMessage(_c, 0, m);
  cMsg_Bc0cJU9O_sendMessage(_c, 0, m);
  cMsg_ofgynSIA_sendMessage(_c, 0, m);
  cMsg_1w5qHdo8_sendMessage(_c, 0, m);
  cMsg_5JlbNHoa_sendMessage(_c, 0, m);
  cMsg_kTAXVVae_sendMessage(_c, 0, m);
  cMsg_8bwmD84w_sendMessage(_c, 0, m);
  cMsg_qrdRDvo6_sendMessage(_c, 0, m);
  cMsg_U7gfNjm6_sendMessage(_c, 0, m);
  cMsg_tkBSdqt0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_c7TnuvkD, 0, m, &cVar_c7TnuvkD_sendMessage);
  cMsg_8D3SHrtK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JOc4gUNL, 0, m, &cVar_JOc4gUNL_sendMessage);
  cMsg_fDu8Ryql_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7AzBkjGy, 0, m, &cVar_7AzBkjGy_sendMessage);
  cMsg_kna4FNWj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Hsop4NoO, 0, m, &cVar_Hsop4NoO_sendMessage);
  cMsg_W3aSvxoC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HkSnukSe, 0, m, &cVar_HkSnukSe_sendMessage);
  cMsg_XVie5Rd3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Gcjymb3k, 0, m, &cVar_Gcjymb3k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LhTRrR5J, 0, m, &cVar_LhTRrR5J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GmG7Z0A3, 0, m, &cVar_GmG7Z0A3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CpIYPq7e, 0, m, &cVar_CpIYPq7e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_atxWBLLw, 0, m, &cVar_atxWBLLw_sendMessage);
  cMsg_2tidil4X_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lKopx8YH, 0, m, &cVar_lKopx8YH_sendMessage);
  cMsg_kyXu3HCq_sendMessage(_c, 0, m);
  cSwitchcase_SZRYyRfP_onMessage(_c, NULL, 0, m, NULL);
  cMsg_c0ISHmmL_sendMessage(_c, 0, m);
  cMsg_aj55TDHx_sendMessage(_c, 0, m);
  cMsg_rnPRTrev_sendMessage(_c, 0, m);
  cSwitchcase_XK62Ipev_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_ej5YC4v1, 0, m, &cVar_ej5YC4v1_sendMessage);
  cMsg_ofzQlBi7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PlTVLrIv, 0, m, &cVar_PlTVLrIv_sendMessage);
  cMsg_YSlGfycc_sendMessage(_c, 0, m);
  cMsg_qxG6eqYT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OqSeOw4v, 0, m, &cVar_OqSeOw4v_sendMessage);
  cMsg_8tUBw3EL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XuFtM1H0, 0, m, &cTabhead_XuFtM1H0_sendMessage);
  cMsg_KwJJr6q3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1mWlg4ka, 0, m, &cVar_1mWlg4ka_sendMessage);
  cMsg_XgwwekLO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sU5zvxGK, 0, m, &cTabhead_sU5zvxGK_sendMessage);
  cMsg_zw651bbS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ApEgP0Xq, 0, m, &cVar_ApEgP0Xq_sendMessage);
  cMsg_TY6U4juR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k4oIYlfJ, 0, m, &cTabhead_k4oIYlfJ_sendMessage);
  cMsg_lZQpt6Bh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gOhnUmKF, 0, m, &cVar_gOhnUmKF_sendMessage);
  cMsg_QPCqunoC_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qF7ovFDX, 0, m, &cTabhead_qF7ovFDX_sendMessage);
  cMsg_rGvRRSrH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sCYjb2Hl, 0, m, &cVar_sCYjb2Hl_sendMessage);
  cMsg_NfVyOLLT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vtr7MPsj, 0, m, &cTabhead_vtr7MPsj_sendMessage);
  cMsg_IdNjwYSi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sGoJGP5L, 0, m, &cVar_sGoJGP5L_sendMessage);
  cMsg_RTg39Stq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Cbu2a9jP, 0, m, &cTabhead_Cbu2a9jP_sendMessage);
  cMsg_gS2mI6Tn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_arFAj48c, 0, m, &cVar_arFAj48c_sendMessage);
  cMsg_uVLSVJSt_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ShQPLGxc, 0, m, &cTabhead_ShQPLGxc_sendMessage);
  cMsg_nHGo37Wf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zNcW3vl4, 0, m, &cVar_zNcW3vl4_sendMessage);
  cMsg_gLo0u6O8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XMjmXHm8, 0, m, &cTabhead_XMjmXHm8_sendMessage);
  cMsg_bVEN6Pwy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VwCYrC2v, 0, m, &cVar_VwCYrC2v_sendMessage);
  cMsg_mtscEtg5_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8Q5xh1TS, 0, m, &cTabhead_8Q5xh1TS_sendMessage);
  cMsg_bPChFr66_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ipge0nuF, 0, m, &cVar_Ipge0nuF_sendMessage);
  cMsg_cW4rDmAQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RcjBGe2N, 0, m, &cTabhead_RcjBGe2N_sendMessage);
  cMsg_DCHn5tRA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2qlQJWGo, 0, m, &cVar_2qlQJWGo_sendMessage);
  cMsg_Gl70eWFW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_a4iWH7aM, 0, m, &cTabhead_a4iWH7aM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Z7Y46nbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_NpRO8Bgi_sendMessage);
}

void Heavy_ChaffVerb::cReceive_rqA4FXQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iumINCfg, 0, m, &cVar_iumINCfg_sendMessage);
}

void Heavy_ChaffVerb::cReceive_f53lGHMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W8PI1Ks0, 0, m, &cVar_W8PI1Ks0_sendMessage);
}

void Heavy_ChaffVerb::cReceive_71cf7esd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_legh2Dm1, HV_BINOP_MULTIPLY, 1, m, &cBinop_legh2Dm1_sendMessage);
}

void Heavy_ChaffVerb::cReceive_n8n97rEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QV6ahpu7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K2Q4k9ix_sendMessage);
}

void Heavy_ChaffVerb::cReceive_yWtioPCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8S6LTRx0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sxXjg6k2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kkLlZuTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AewI9EU3, 0, m, &cVar_AewI9EU3_sendMessage);
}

void Heavy_ChaffVerb::cReceive_M2eAU6oA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xbmerv5b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y0m9Hj0m, 0, m, &cVar_y0m9Hj0m_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mw3Yee1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_xBjcimm3_sendMessage);
}

void Heavy_ChaffVerb::cReceive_iuORahhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_njw3luQs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eqy0F4yQ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_dJf2VUwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b8XUaSwk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_deo0CsBj_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3wqtwbAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jk5cOU1W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KsKRP83f_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3YUFAfL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LbpWFsSl, m);
}

void Heavy_ChaffVerb::cReceive_Od6oYqC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_V4qjl42r, m);
}

void Heavy_ChaffVerb::cReceive_4yXeuyzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LhTRrR5J, 0, m, &cVar_LhTRrR5J_sendMessage);
}

void Heavy_ChaffVerb::cReceive_v9ppyIbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_iFy8oZvb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_liyVNj4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eWrLPeWY, 0, m, &cVar_eWrLPeWY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_nQEK0weP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TaxVq1PI, 0, m, &cVar_TaxVq1PI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ui8H2ZCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HkSnukSe, 0, m, &cVar_HkSnukSe_sendMessage);
}

void Heavy_ChaffVerb::cReceive_5xpfIfpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8DlmzqPN, m);
}

void Heavy_ChaffVerb::cReceive_OxVh5UYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_o0Y5WOuF, m);
}

void Heavy_ChaffVerb::cReceive_HHqhJnin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lewcrIg, HV_BINOP_MULTIPLY, 1, m, &cBinop_8lewcrIg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dhadvgLD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_svkkmqQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kdtccGXc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y2qdH11F_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_KBqMzKSc, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_zJtUp23j, VOf(Bf4));
    __hv_line_f(&sLine_qyvbQuC8, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_sI3uoCMZ, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_QHaWdY5K, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_33hpWEM1, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_0bbw6Ji8, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_pJtrqzXF, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_JpHslDDO, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_rp0wlpFF, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_I65smqJg, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_OrdTojmI, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_P6LFPaT4, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ix3PpzZt, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_Fly7dUJi, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_REzBjicD, VIf(I0));
    __hv_varread_f(&sVarf_OMh96Snw, VOf(Bf2));
    __hv_rpole_f(&sRPole_MvbpORTq, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_BP2vBDbu, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_xUIGOJNt, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_8DlmzqPN, VOf(Bf1));
    __hv_tabread_f(&sTabread_ToDGYBaJ, VOf(Bf5));
    __hv_varread_f(&sVarf_o0Y5WOuF, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_LsxhWH34, VIf(Bf9));
    __hv_varread_f(&sVarf_V4qjl42r, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_XN3xD77l, VOf(Bf9));
    __hv_varread_f(&sVarf_wpYfVd94, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_0yuIjbUX, VOf(Bf2));
    __hv_rpole_f(&sRPole_oZUfZ0P4, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_CH5mHjGq, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_AQ2mKBFw, VOf(Bf2));
    __hv_tabread_f(&sTabread_pf1cY1OZ, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_dQGshT1h, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_CGNBqTxo, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_Ar597HbC, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_ac5G6h9O, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_PlP7xxbO, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_agVDldlT, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_yVHo2jC2, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_8vhIuJU1, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_cT1TOIgt, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_Lua8jujC, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_6BE9JuDb, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_0NB9mQvI, VOf(Bf9));
    __hv_varread_f(&sVarf_GgRgiQ3q, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_324nPTEl, VOf(Bf3));
    __hv_rpole_f(&sRPole_qSCUvnDo, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_5zeiANgd, VOf(Bf3));
    __hv_varread_f(&sVarf_o140dlFp, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_McgoWCYH, VOf(Bf12));
    __hv_rpole_f(&sRPole_fypMuiNt, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_KxdxpacY, VOf(Bf12));
    __hv_varread_f(&sVarf_FdTt7rFV, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_RPMr8mCh, VOf(Bf11));
    __hv_rpole_f(&sRPole_mHxzWSA3, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_Be2e7QTJ, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_3i2N9rQ8, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_ndgyGCyS, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_r9yAMZTg, VIf(Bf11));
    __hv_line_f(&sLine_7tzfj00M, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_LbpWFsSl, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
